import QtQuick 1.1

SettingsPage {
    id: connection

    internalDelegate: WirelessSettingsDelegate {
        onClicked: {
            invokeCurrent("")
        }
    }

    property bool displayMessage: model === undefined ? false : model.displayMessage
    onDisplayMessageChanged: messageLoader.source = displayMessage ? "MessageBox.qml" : ""

    property bool displayPairingMessage: model === undefined
                                         ? false
                                         : model.displayPairingMessage
    onDisplayPairingMessageChanged: pairingMessageLoader.source = displayPairingMessage
                                    ? "MessageBox.qml"
                                    : ""

    property bool hidePage: model === undefined ? false : model.hidePage
    onHidePageChanged: {
        if (hidePage) {
            connection.hide()
            model.hidePage = false
        }
    }

    // Dialog pop-up which can be shown if i.e. no devices are found.
    Loader {
        id: messageLoader
        onLoaded: {
            item.title = qsTrId("ID_SETUP_BLUETOOTH_NO_DEVICE_FOUND_TITLE") + translation.update
            item.text = qsTrId("ID_SETUP_BLUETOOTH_NO_DEVICE_FOUND_MESSAGE") + translation.update
            item.cancelButtontext = qsTrId("ID_BUTTON_CANCEL") + translation.update
            item.okButtontext = qsTrId("ID_SETUP_BLUETOOTH_NO_DEVICE_FOUND_REFRESH_BUTTON") + translation.update
            item.iconStyle = item.iconEnum.info

            item.show()
            item.forceActiveFocus()
        }
    }

    // Dialog pop-up which can be shown if i.e. no devices are found.
    Loader {
        id: pairingMessageLoader
        onLoaded: {
            item.title = qsTrId("ID_SETUP_BLUETOOTH_UNABLE_TO_PAIR_TITLE") + translation.update
            item.text = qsTrId("ID_SETUP_BLUETOOTH_UNABLE_TO_PAIR_BODY") + translation.update
            item.hasButtons = false
            item.iconStyle = item.iconEnum.info

            item.show()
            item.forceActiveFocus()
        }
    }

    Connections {
        target: messageLoader.item

        onCancelSelected: {
            model.displayMessage = false
            connection.hide()
        }

        onOkSelected: {
            model.displayMessage = false
            model.isNowActive(true)
        }
    }

    Connections {
        target: pairingMessageLoader.item
        onCancelSelected: model.displayPairingMessage = false
    }

}
