import QtQuick 1.1

//facet 'greenbox' enums are exposed via qmlRegisterType(FLIR::UI::Interface) in c++
import GreenBox 1.0
import se.flir 1.0

// Desktop
// -------
// The "transparent" item that is the parent of all other QML elements.

FocusScope {

    // Signals

    signal showArchive
    signal triggerActionRequest
    signal exitEdit()
    property variant lastMenu: 0

    // slots (called from the xml file for the globalMessageSpinner)
    function focusDesktopFocusGroup() {
        focus = true;
    }
    function setMainMenu() {
        menus.activeMenu = Menus.MainMenu
    }
    function adaptMenu() {
        greenbox.adaptMenu()
    }

    //todo: review if this is the right way to dispatch arrow keys
    signal key_down(int key, int repeat)
    signal key_up(int key, int repeat)

    // Property values

    id: desktop
    anchors.fill: parent
    width: grid.width
    height: grid.height

    property bool longTapped: false

    // Debug output

    //onShowArchive: console.log("Desktop::showArchive()")

    // Touch and keyboard handling
    MouseArea {
        anchors.fill: parent
        onPressed: {
            if (!menus.menuOpen)
                longTapTimer.start()
        }

        onReleased: {
            // this is slighly tricky, the longTapTimer opens the menu, quickly followed by
            // the onReleased being called when the user releases the mouse. We have to avoid
            // closing it immediately after opening.
            if (menus.activeMenu === Menus.ZoomPopupMenu)
            {
                // but later, if the user clicks again, we have to close the zoom popup again
                // on single click.
                if (!longTapTimer.running)
                    menus.closeMenu();
            }
            else
               menus.toggleMenu(); // open the main menu
            longTapTimer.stop()
        }
    }

    Timer {
        id: longTapTimer
        interval: 500
        repeat: true
        onTriggered: {
            if (running) {
                menus.openTemporary(Menus.ZoomPopupMenu);
            }
        }
    }

    Timer {
        id: longPressArchiveTimer
        interval: 1000
        onTriggered: {
            greenbox.system.doNuc()
        }
    }

    Connections { // get keyboard focus from menu to our focus-scope again after it closes.
        target: menus
        onMenuClosed: desktop.focus = true;
    }


    Connections { // Listen to when the measurements are no longer active (and set our menus)
        target: oldMeasurements
        onSelectionChanged: {
            if (! oldMeasurements.hasSelection && !menus.menuOpen) {
                adaptMenu()
                // just to be on the safe side, give explicit focus to desktop.
                // This is a no-op in many cases since desktop is a FocusScope,
                // so it would never take away focus from a child of desktop
                // It is needed when deleting measurement function to avoid losing focus.
                desktop.focus = true
            }
        }
    }

    Keys.onPressed: {
        if (event.key === keys.trigger) {
            triggerActionRequest()
            event.accepted = true
        }
        else if (event.key === keys.up) {
            key_down(GreenBox.UI_KEY_UP,event.isAutoRepeat === true?1:0)
            event.accepted = true
        }
        else if (event.key === keys.down) {
           key_down(GreenBox.UI_KEY_DOWN,event.isAutoRepeat === true?1:0)
            event.accepted = true
        }
        else if (event.key === keys.left) {
            key_down(GreenBox.UI_KEY_LEFT,event.isAutoRepeat === true?1:0)
            event.accepted = true
        }
        else if (event.key === keys.right) {
            key_down(GreenBox.UI_KEY_RIGHT,event.isAutoRepeat === true?1:0)
            event.accepted = true
        }
        else if (event.key === keys.onOff) {
            key_down(GreenBox.UI_KEY_ONOFF,event.isAutoRepeat === true?1:0)
            event.accepted = true
        }
        else if (event.key === keys.archive)
        {
            if (event.isAutoRepeat === false)
                longPressArchiveTimer.start()
            event.accepted = true
        }

        // Debug code - testing set/get of resources
//        else if (event.key === Qt.Key_1) {
//            greenbox.setResource(".image.sysimg.measureFuncs.mbox.1.active", "true")
//        }
//        else if (event.key === Qt.Key_2) {
//            greenbox.setResource(".image.sysimg.measureFuncs.mbox.1.active", "false")
//        }
    }

    Keys.onReleased: {
        if (event.key === keys.archive) {
            if (event.isAutoRepeat === false)
            {
                if (greenbox.appState === GreenBox.FacetEditView)
                {
                    console.log("Any action on this?")
                }
                else if (longPressArchiveTimer.running)
                {
                    longPressArchiveTimer.stop()

                    if (greenbox.mediaControl.mediaControlVisual === MediaControl.MEDIA_CONTROL_VISUAL_STILL_SAVE_STARTED ||
                            greenbox.mediaControl.mediaControlVisual === MediaControl.MEDIA_CONTROL_VISUAL_STILL_SAVING) {
                        console.log("Ignore going into archive when saving!")
                    }
                    else {
                        showArchive()
                    }
                }
            }
            event.accepted = true
        }
        else if (event.key === keys.select) {
            if (event.isAutoRepeat === false)
                menus.toggleMenu()
            event.accepted = true
        }
        else if (event.key === keys.up) {
            key_up(GreenBox.UI_KEY_UP,event.isAutoRepeat === true?1:0)
            event.accepted = true
        }
        else if (event.key === keys.down) {
           key_up(GreenBox.UI_KEY_DOWN,event.isAutoRepeat === true?1:0)
            event.accepted = true
        }
        else if (event.key === keys.left) {
            key_up(GreenBox.UI_KEY_LEFT,event.isAutoRepeat === true?1:0)
            event.accepted = true
        }
        else if (event.key === keys.right) {
            key_up(GreenBox.UI_KEY_RIGHT,event.isAutoRepeat === true?1:0)
            event.accepted = true
        }
        else if (event.key === keys.onOff) {
            key_up(GreenBox.UI_KEY_ONOFF,event.isAutoRepeat === true?1:0)
            event.accepted = true
        }
    }



    Item {
        id: liveControls
        anchors.fill: parent
        visible: greenbox.appState !== GreenBox.FacetArchiveView

        // FLIR logo
        Image {
            id: logo
            source: "../images/Sc_Logo_FlirHardEdges.png"
            visible: greenbox.appState !== GreenBox.FacetArchiveView

            // Tilt properties
            rotation: 0
            transformOrigin: Item.BottomLeft
            state: {
                if (greenbox.system.tilt === 0)
                    return "0"
                else if (greenbox.system.tilt === 90)
                    return "90"
                else if (greenbox.system.tilt === 180)
                    return "180"
                else
                    return "270"
            }

            // Tilt states
            states: [
                State {
                    name: "0"
                    PropertyChanges { target: logo; rotation: 0 }
                    PropertyChanges { target: logo; x: grid.leftMargin + grid.irLeftMargin + grid.horizontalSpacing }
                    PropertyChanges { target: logo; y: grid.height - grid.bottomMargin - grid.verticalSpacing - height }
                },
                State {
                    name: "90"
                    PropertyChanges { target: logo; rotation: 90 }
                    PropertyChanges { target: logo; x: grid.leftMargin + grid.irLeftMargin + grid.horizontalSpacing }
                    PropertyChanges { target: logo; y: grid.topMargin + grid.verticalSpacing - height }
                },
                State {
                    name: "180"
                    PropertyChanges { target: logo; rotation: 180 }
                    PropertyChanges { target: logo; x: grid.width - grid.leftMargin - grid.irLeftMargin - grid.horizontalSpacing }
                    PropertyChanges { target: logo; y: -height + grid.topMargin + grid.verticalSpacing }
                },
                State {
                    name: "270"
                    PropertyChanges { target: logo; rotation: 270 }
                    PropertyChanges { target: logo; x: grid.width - grid.horizontalSpacing - grid.rightMargin - grid.irRightMargin }
                    PropertyChanges { target: logo; y: grid.height - grid.bottomMargin - grid.verticalSpacing - height }
                }
            ]
        }

        StatusRow { }

        TempScale { }

        MeasureTools {
            width: grid.width - grid.irLeftMargin - grid.irRightMargin
            height: grid.height
            x: grid.irLeftMargin
        }
    }
}
