import QtQuick 1.1
import se.flir 1.0

// This object/item represents the voice playback/recording (annotation) status
// bar. The status bar consists of two things: An optional recording text label
// and a mandatory time label is the format of MM:SS.
//
// The text labels are managed within a row and should in theory work with
// languages which goes from right to left. Further testing needed.
//
// The visibilty and status of the DurationStatusBar is handled by the
// ArchiveHandler class.
Rectangle {
    id: durationStatusBar

    property string durationTime: "00:00"

    // See the import for information about ArchiveHandler. Also, see the class
    // ArchiveHandler for the enumerations.
    visible: archiveHandler.audioStatus !== ArchiveHandler.Idle
//    visible: true
    onVisibleChanged: {
        durationTime = "00:00"
    }

    // The size of the durationStatusBar (and its border) should be bigger than
    // the two text fields within the row.
    width: statusBarRow.width + grid.horizontalSpacing * 4
    height: statusBarRow.height

    y: grid.topMargin + grid.verticalSpacing
    anchors.horizontalCenter: parent.horizontalCenter

    // Make the rectangle transparant so our border doesn't have a white back-
    // ground.
    color: "transparent"

    Timer {
        id: tickTimer
        interval: 1000
        running: durationStatusBar.visible
        repeat: true

        onTriggered: {
            var progress = archiveHandler.audioProgress
            var minutes = Math.floor(progress / 60)
            var seconds = progress % 60

            // Pad with zeros when needed.
            durationStatusBar.durationTime
                    = (minutes < 10 ? "0" : "") + minutes
                    + ":"
                    + (seconds < 10 ? "0" : "") + seconds
        }
    }

    // The background image, which is used for filling up all the space required
    // by durationStatusBar.
    RoundedRect {
        anchors.fill: durationStatusBar
    }

    // The text labels reside within the row. The text labels are separated with
    // a spacing, and centered in durationStatusBar.
    Row {
        id: statusBarRow
        spacing: grid.horizontalSpacing * 4

        height: grid.resultTableRowHeight
        anchors.centerIn: durationStatusBar

        Text {
            id: recordingLabel

            visible: archiveHandler.audioStatus === ArchiveHandler.Recording
//            visible: true

            anchors.verticalCenter: statusBarRow.verticalCenter

            font.family: fonts.latinFamily
            font.pixelSize: fonts.smallSize
            color: colors.textFocused
            text: visible ? qsTrId("ID_RECORDING") + translation.update : ""
        }

        Text {
            id: durationLabel

            visible: durationStatusBar.visible

            anchors.verticalCenter: statusBarRow.verticalCenter

            font.family: fonts.latinFamily
            font.pixelSize: fonts.smallSize
            color: colors.textFocused
            text: durationStatusBar.durationTime

            property int wantedWidth: width

            // Allow the text width to grow, but not to shrink.
            onImplicitWidthChanged: {
                if (implicitWidth > width) {
                    width = implicitWidth
                    wantedWidth = implicitWidth
                }
                else {
                    width = wantedWidth
                }
            }
        }
    }
}
