import QtQuick 1.1
import se.flir 1.0

Item {

    width: grabImageId.width
    height: grabImageId.height
    x: index === 0 || index === 1 ? 0 : index === 4 ? (parent.width - width) / 2 : parent.width - width
    y: index === 0 || index === 2 ? 0 : index === 4 ? (parent.height - height) / 2 : parent.height - width

    MouseArea {

        anchors.fill: parent
        anchors.topMargin: -10
        anchors.leftMargin: -10
        anchors.rightMargin: -10
        anchors.bottomMargin: -10

        drag.target: boxId
        drag.minimumX: 0
        drag.minimumY: 0
        drag.maximumX: grid.width - boxId.width - grid.irLeftMargin - grid.irRightMargin - 1
        drag.maximumY: grid.height - boxId.height - 1

        property bool ignoreMouseX: true
        property bool ignoreMouseY: true
        property int grabOffsetX: 0
        property int grabOffsetY: 0

        onMouseXChanged: {
            if (ignoreMouseX === false)  // avoid jerky jump when first grabbing box
            {
                if (Math.abs(mouseX) > 5)
                    boxId.moved = true

                var myMouseX = mouseX - grabOffsetX

                if (index === 0 || index === 1)
                {
                    if (boxId.width - myMouseX > 10)
                    {
                        boxId.x = boxId.x + myMouseX
                        boxId.width = boxId.width - myMouseX
                        if (boxId.x < 0)
                        {
                            boxId.width = boxId.width + boxId.x
                            boxId.x = 0
                        }
                    }
                }
                else if (index === 2 || index === 3)
                {
                    if (boxId.width + myMouseX > 10)
                    {
                        boxId.width = boxId.width + myMouseX
                        if (boxId.width + boxId.x > grid.width - grid.irLeftMargin - grid.irRightMargin)
                            boxId.width = grid.width - grid.irLeftMargin - grid.irRightMargin - boxId.x
                    }
                }
            }
            else
            {
                ignoreMouseX = false
                grabOffsetX = mouseX
            }
        }

        onMouseYChanged: {
            if (ignoreMouseY === false) // avoid jerky jump when first grabbing box
            {
                if (Math.abs(mouseY) > 5)
                    boxId.moved = true

                var myMouseY = mouseY - grabOffsetY

                if (index === 0 || index === 2)
                {
                    if (boxId.height - myMouseY > 10)
                    {
                        boxId.y = boxId.y + myMouseY
                        boxId.height = boxId.height - myMouseY
                    }
                }
                else if (index === 1 || index === 3)
                {
                    if (boxId.height + myMouseY > 10)
                        boxId.height = boxId.height + myMouseY
                }
            }
            else
            {
                ignoreMouseY = false
                grabOffsetY = mouseY
            }
        }

        onPressAndHold: {
            if (boxId.moved === false)
            {
                menus.activeMenu = Menus.MeasurementMenu
                menus.toggleMenu()
                drag.target = undefined
            }
        }

        onPressed: {
            if (activeFocus === false && selected === false)
            {
                forceActiveFocus()
                measureTools.sendEnterMFuncEditRequest(type, resIndex - 1)
                menus.closeMenu()
            }
            if (selectionMoveMode)
            {
                if (index !== 4)
                    oldMeasurements.setSelectionMoveMode(false)
            }
            else if (index === 4)
                oldMeasurements.setSelectionMoveMode(true)

            boxId.dragStartX = boxId.x
            boxId.dragStartY = boxId.y

            if (index !== 4)
                drag.target = undefined

            ignoreMouseX = true
            ignoreMouseY = true
        }

        onReleased: {
            boxId.moved = false
            drag.target = boxId

            oldMeasurements.setPosition(resIndex-1, boxId.x, boxId.y, boxId.width, boxId.height)
        }
    }

    Image {
        id: grabImageId
        source: {
            if (selected)
            {
                if (selectionMoveMode)
                {
                    if (index === 4)
                        return "../images/Sc_MeasureToolPlacedSelected_Marker_Sel.png"
                    else
                        return "../images/Sc_MeasureToolPlacedSelected_Marker_Def.png"
                }
                else
                {
                    if (index === 4)
                        return "../images/Sc_MeasureToolPlacedSelected_Marker_Def.png"
                    else
                        return "../images/Sc_MeasureToolPlacedSelected_Marker_Sel.png"
                }
            }
            else
            {
                if (index === 0)
                    return "../images/Sc_MeasureToolPlaced_BoxTopLeft_Def.png"
                else if (index === 1)
                    return "../images/Sc_MeasureToolPlaced_BoxBottomLeft_Def.png"
                else if (index === 2)
                    return "../images/Sc_MeasureToolPlaced_BoxTopRight_Def.png"
                else if (index === 3)
                    return "../images/Sc_MeasureToolPlaced_BoxBottomRight_Def.png"
                else if (index === 4)
                    return ""
            }
        }
    }
}
