import QtQuick 1.1

FocusScope {
    id: messageSpinner
    anchors.fill: parent
    visible: false
    z: 100

    //! Change this to set the title of the message box.
    property string title

    signal hideRequested
    signal focusDesktopFocusGroup

    function show() {
        visible = true
        transparantBorder.forceActiveFocus()
    }

    function showUsingTitle(titleString) {
        messageSpinner.title = titleString

        visible = true
        transparantBorder.forceActiveFocus()
    }

    function hide() {
        visible = false
        focusDesktopFocusGroup()
    }



    MouseArea {
        anchors.fill: parent
        onClicked: hideRequested()
    }


    Rectangle {
        id: transparantBorder
        anchors.fill: messageSpinner
        opacity: 0.5
        color: "black"

        Keys.onPressed: event.accepted = true
        Keys.onReleased: {
            event.accepted = true

            if (event.key === keys.back || (event.key === keys.left && basePage === false))
                hideRequested()
        }
    }

    Image {
        id: frameImage

        source: "../images/Bg_DialoguePopUp_MiniBg_Def.png"
        anchors.centerIn: transparantBorder
    }

    Image {
        id: infoImage
        source: "../images/Ic_GlobalDialogue_Info_Sel.png"
        anchors.verticalCenter: frameImage.verticalCenter
        anchors.left: frameImage.left
        anchors.leftMargin: grid.horizontalSpacing * 4
    }

    Text {
        id: titleText

        text: qsTrId(messageSpinner.title) + translation.update

        anchors.verticalCenter: frameImage.verticalCenter
        anchors.left: infoImage.right
        anchors.right: spinner.left

        font.family: fonts.family
        font.pixelSize: fonts.smallSize
        font.bold: true
        color: colors.textFocused
        wrapMode: Text.Wrap
    }

    Spinner {
        id: spinner

        anchors.verticalCenter: frameImage.verticalCenter
        anchors.right: frameImage.right
        anchors.rightMargin: grid.horizontalSpacing * 6

        //! @todo Fixed size, fix?
        width: 16
        height: 16
    }
}
