import QtQuick 1.1

// NotificationArea
// ----------
// Notification area that displays short transient non-modal messages

Item {

    signal notificationAreaClosed()

    id: notificationArea
    anchors.horizontalCenter: parent.horizontalCenter
    y: grid.topMargin + grid.verticalSpacing
    width: grid.horizontalSpacing * 4 + messageLabel.width + iconImage.width
    height: (grid.resultTableRowHeight + grid.verticalSpacing) * messageLabel.lineCount - grid.verticalSpacing
    visible: !pogo && messageLabel.text !== ""

    Timer {
        id: minimumDisplayTimeTimer
        interval: 4000
        onTriggered: { minimumDisplayTimeTimer.stop(); hide() }
    }

    function show(error) {
        iconImage.visible = false
        doShow(error)
    }
    function showIconText(icon, error) {
        if (icon === "EXCLAMATION")
        {
            iconImage.source = "../images/Sc_Status_Warning_Def.png"
            iconImage.visible = true
        }
        doShow(error)
    }

    function doShow(error) {
        if (error !== undefined)
        {
            messageLabel.text = qsTrId(error)
            if (messageLabel.implicitWidth > grid.width - 2 * grid.cellWidth)
                messageLabel.width = grid.width - 2 * grid.cellWidth
            minimumDisplayTimeTimer.restart()
        }
    }

    function hide() {
        if (minimumDisplayTimeTimer.running === false)
        {
            messageLabel.text = ""
            messageLabel.width = undefined
            notificationAreaClosed()
            iconImage.visible = false
        }
    }

    // The background
    BorderImage {
        id: backgroundImage
        anchors.fill: parent
        border { left: grid.unit; top: grid.unit; right: grid.unit; bottom: grid.unit }
        source: "../images/Bg_Notification_Bar_Def.png"
    }

    Image {
        id: iconImage
        anchors.left: notificationArea.left
        anchors.leftMargin:  grid.horizontalSpacing
        anchors.verticalCenter: parent.verticalCenter
        width: visible ? sourceSize.width : 0
        visible: false
    }

    // The message
    Text {
        id: messageLabel
        anchors.left: iconImage.right
        anchors.leftMargin: iconImage.visible ? 0 : 2 * grid.horizontalSpacing
        anchors.verticalCenter: parent.verticalCenter
        font.family: fonts.family
        font.pixelSize: fonts.smallSize
        color: colors.textFocused
        wrapMode: Text.WordWrap
    }
}
