import QtQuick 1.1
import se.flir 1.0

// PreviewArchive
// --------------
// The preview archive.

ListView {

    // Signals and properties
    signal showThumbnailArchive
    signal showArchiveToolBar
    signal delegateDestroyed(int index)
    model: archiveModel

    property bool goingLeft: false
    property bool goingRight: false
    property int moveDuration: 1
    property int indicatorTime: 100

    Timer {
        id: indicatorTimer
        interval: indicatorTime
        onTriggered: {
            if (goingLeft)
                goingLeft = false
            if (goingRight)
                goingRight = false
        }
    }

    function goLeft() {
        if (currentIndex > 0)
        {
            goingLeft = true
            decrementCurrentIndex()
            if (indicatorTimer.running)
                indicatorTimer.restart()
            else
                indicatorTimer.start()
        }
    }

    function goRight() {
        if (currentIndex < (count - 1))
        {
            goingRight = true
            incrementCurrentIndex()
            if (indicatorTimer.running)
                indicatorTimer.restart()
            else
                indicatorTimer.start()
        }
    }

    function goUp() {
        currentItem.decrementCurrentIndex()
    }

    function goDown() {
        currentItem.incrementCurrentIndex()
    }

    function tapAction(coord)
    {
        if(previewArchive.currentItem.videoPlayIcon !== null)
        {
//            console.log("tapTarget null?" + (previewArchive.currentItem.videoPlayIcon === null))
//            console.log("tapTarget undefined?" + (previewArchive.currentItem.videoPlayIcon === undefined))
//            console.log("x <<" + previewArchive.currentItem.videoPlayIcon.x)
//            console.log("y <<" + previewArchive.currentItem.videoPlayIcon.y)
//            console.log("h <<" + previewArchive.currentItem.videoPlayIcon.height)
//            console.log("w <<" + previewArchive.currentItem.videoPlayIcon.width)
//            console.log("ObjectName <<" + previewArchive.currentItem.videoPlayIcon.objectName + ">>")
//            console.log("ObjectId <<" + previewArchive.currentItem.videoPlayIcon.id + ">>")

//            console.log("click x:" + coord.x)
//            console.log("click y:" + coord.y)

            var iconRelativeCoord = previewArchive.mapToItem(previewArchive.currentItem.videoPlayIcon, coord.x, coord.y)
//            console.log("iconRelativeCoord x:" + iconRelativeCoord.x)
//            console.log("iconRelativeCoord y:" + iconRelativeCoord.y)


            if(iconRelativeCoord.x > 0 &&
               iconRelativeCoord.x < previewArchive.currentItem.videoPlayIcon.width &&
               iconRelativeCoord.y > 0 &&
               iconRelativeCoord.y < previewArchive.currentItem.videoPlayIcon.height)
            {
                console.log("enterVideoPlayback")
                archiveHandler.enterVideoPlayback()
                return
            }
        }
        console.log("toggle ArchiveToolBar")
        menus.toggleMenu()
    }

    // Debug output

//    onShowThumbnailArchive: console.log("PreviewArchive::showThumbnailArchive()")
//    onDelegateDestroyed: console.log("PreviewArchive::delegateDestroyed(" + index + ")")
//    onShowArchiveToolBar: console.log("PreviewArchive::showToolBar()")

    // Property values

    id: previewArchive
    anchors.fill: parent
    orientation: ListView.Horizontal
    snapMode: ListView.SnapOneItem
    highlightRangeMode: ListView.StrictlyEnforceRange
    highlightMoveDuration: moveDuration
    cacheBuffer: width
    interactive: false

    // The left and right arrows
    Image {
        id: leftArrow
        anchors.verticalCenter: parent.verticalCenter
        anchors.left: parent.left
        anchors.leftMargin: grid.leftMargin + grid.irLeftMargin - grid.horizontalSpacing
        source: goingLeft ? "../images/Ic_List_ArrowLeft_Sel.png" : "../images/Ic_List_ArrowLeft_Def.png"
        visible: currentIndex > 0 && !moving
    }

    Image {
        id: rightArrow
        anchors.verticalCenter: parent.verticalCenter
        anchors.right: parent.right
        anchors.rightMargin: grid.rightMargin - grid.horizontalSpacing
        source: goingRight ? "../images/Ic_List_ArrowRight_Sel.png" : "../images/Ic_List_ArrowRight_Def.png"
        visible: currentIndex < (count - 1) && !moving
    }

    delegate: PreviewDelegate {
        Component.onDestruction: delegateDestroyed(index)
        property variant data: model
    }

    MouseArea {
        id: swipeArea
        width: grid.width
        height: grid.height

        property real startX: 0
        property real startY: 0
        property real deltaLimit: 30
        onPressed: {
            startX = mouseX
            startY = mouseY
        }

        onReleased: {
            var deltaX = mouseX-startX
            var deltaY = mouseY-startY
            var absX = deltaX > 0 ? deltaX : -deltaX
            var absY = deltaY > 0 ? deltaY : -deltaY

            var coord = mapToItem(previewArchive,mouseX,mouseY)

            if (absX > absY)
            {
                if (deltaX > deltaLimit)
                    goLeft()
                else if (deltaX < -deltaLimit)
                    goRight()
                else
                    tapAction(coord)
            }
            else
            {
                if (deltaY > deltaLimit)
                    goDown()
                else if (deltaY < -deltaLimit)
                    goUp()
                else
                    tapAction(coord)

            }
        }
    }

    // The bottom row
    Item {
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.bottomMargin: grid.bottomMargin
        // Magic number... to be replaced, but not sure with what
        height: 14

        // Group name, file name and arrows

        Item {
            anchors.fill: parent
            visible: (currentIndex < 0) ? false : previewArchive.currentItem.data.groupSize > 1

            Text {
                id: groupNameText
                anchors.centerIn: parent
                font.family: fonts.family
                font.pixelSize: fonts.smallSize
                color: colors.textFocused
                text: (currentIndex < 0) ? "" : previewArchive.currentItem.data.groupName
            }

            Image
            {
                id: upDownArrow
                anchors.verticalCenter: groupNameText.verticalCenter
                anchors.left: groupNameText.right
                source: "../images/Ic_List_ArrowUpDown_Def.png"
            }
        }

        // Just file name if only one image in group

        Text {
            anchors.centerIn: parent
            font.family: fonts.family
            font.pixelSize: fonts.smallSize
            color: colors.textFocused
            visible: (currentIndex < 0) ? false : previewArchive.currentItem.data.groupSize === 1
            text: (currentIndex < 0) ? "" : previewArchive.currentItem.data.currentShortName
        }
    }

    onCurrentIndexChanged: {
        archiveModel.currentIndex = currentIndex
        if (currentItem !== null && currentItem.currentIndex !== 0)
        currentItem.resetCurrentIndex()
        console.log("onCurrentIndexChanged")
    }

    // Animation

    Behavior on opacity {
        NumberAnimation {
            duration: 300
            easing.type: Easing.InOutQuad
        }
    }

    // Keyboard handling

    Keys.onPressed: {
        if (event.key === keys.left) {
            goLeft()
            event.accepted = true
        }
        else if (event.key === keys.right) {
            goRight()
            event.accepted = true
        }
        else if (event.key === keys.up) {
            goUp()
            event.accepted = true
        }
        else if (event.key === keys.down) {
            goDown()
            event.accepted = true
        }
    }

    Keys.onReleased: {
        if (event.key === keys.back) {
            showThumbnailArchive()
            event.accepted = true
        }
        else if (event.key === keys.select) {
            showArchiveToolBar()
            event.accepted = true
        }
    }
}
