import QtQuick 1.1
import se.flir 1.0

// PreviewDelegate
// ----------------
// Delegate for the PreviewArchive element.

Rectangle {

    // Property values
    property variant videoPlayIcon

    id: previewDelegate
    width: grid.width
    height: grid.height
    color: colors.background

    Component.onCompleted: {
        groupView.highlightMoveDuration = 1
        groupView.currentIndex = groupView.model.currentIndex
        groupView.highlightMoveDuration = 100
    }

    // Functions

    function decrementCurrentIndex() {
        groupView.decrementCurrentIndex()
    }

    function incrementCurrentIndex() {
        groupView.incrementCurrentIndex()
    }

    function resetCurrentIndex() {
        groupView.currentIndex = 0
    }

    // The view showing the current image

    // Expose the current source path to the archive.
    property variant frontSource: groupView.currSource

    PathView {
        id: groupView
        anchors.centerIn: parent
        width: grid.previewWidth
        height: grid.previewHeight
        interactive: false

        model: groupModel

        // The current path will be stored here by the delegate.
        property string currSource: "someValue"

        delegate: Image {
            id: imageItem
            width: grid.previewWidth
            height: grid.previewHeight
            z: PathView.pathZ
            scale: PathView.pathScale
            opacity: PathView.pathOpacity
            sourceSize.width: grid.previewWidth
            sourceSize.height: grid.previewHeight
//            asynchronous: true
            cache: false
            source: "image://archiveImageProvider/preview_" + imageKey + "_" + imageVersion + "_" + currentPrimaryImageKey

            // Propagate the current path up so it can be read from the outside! (slightly complicated...)
            Binding {
                property: "currSource"
                target: groupView
                value: source
                when: imageItem.PathView.isCurrentItem
            }

            Binding {
                property: "videoPlayIcon"
                target: previewDelegate
                value: groupModel.itemType === ArchiveGroupModel.ITEM_TYPE_VIDEO ?videoIndicationOverlay : null
                when: imageItem.PathView.isCurrentItem
            }

            BorderImage {
                anchors.fill: parent
                asynchronous: false
                cache: true
                border { left: 5; top: 5; right: 5; bottom: 5 }
                source: imageItem.status === Image.Ready ?
                            "../images/Bg_ArchiveViewPreview_ImgOutline_Def.png" :
                            (imageItem.status === Image.Loading ?
                                 "../images/Bg_ArchiveViewPreview_ImgNotLoaded_Def.png" :
                                 "../images/Bg_ArchiveViewPreview_ImgNotFound_Def.png")
            }

            Image{
                id: videoIndicationOverlay
                objectName: "videoIndicationOverlayObject"
                visible: groupModel.itemType === ArchiveGroupModel.ITEM_TYPE_VIDEO
                anchors.centerIn: parent
                source: groupModel.itemType === ArchiveGroupModel.ITEM_TYPE_VIDEO ? "../images/Sc_Video_Directplay_Def.png" : ""
            }

            // Just for debugging
//            Text
//            {
//                color: "cyan"
//                text: "key: " + imageKey + ":" + currentPrimaryImageKey + " - v: " + version
//                height: 32
//                font.pixelSize: 32
//            }

            // This seems to eat up a lot of memory, not sure why...
//            AnimatedImage {
//                anchors.fill: parent
//                asynchronous: false
//                cache: true
//                source: "../images/Bg_ArchiveViewPreview_ImgNotLoaded_Def.gif"
//                visible: imageItem.status === Image.Loading
//            }
        }

        path: Path {
            startX: grid.previewWidth / 2
            startY: grid.previewHeight / 2
            PathAttribute { name: "pathZ"; value: 1.0 }
            PathAttribute { name: "pathScale"; value: 1.0 }
            PathAttribute { name: "pathOpacity"; value: 1.0 }
            PathQuad {
                x: grid.previewWidth / 2
                y: grid.previewHeight / 2
                controlX: grid.previewWidth / 2
                controlY: grid.previewHeight / 2 - 20
            }
            // PathPercent{ value: 0.55 }
            PathAttribute { name: "pathZ"; value: 0.0 }
            PathAttribute { name: "pathScale"; value: 0.85 }
            PathAttribute { name: "pathOpacity"; value: 0.5 }
            PathQuad {
                x: grid.previewWidth / 2
                y: grid.previewHeight / 2
                controlX: grid.previewWidth / 2
                controlY: grid.previewHeight / 2 - 45 // TODO this '45' will only work for the e2/astra screensizes...
            }
        }

        onCurrentIndexChanged: model.currentIndex = currentIndex
    }
}
