import QtQuick 1.1
import GreenBox 1.0

// SavePreview
// ----------
// The save preview, shown at the bottom of the screen while saving

Item {

    // Property values
    property bool isVisible: false

    id: savePreview
    x: ( grid.width - width ) / 2
    y: grid.height
//    width: grid.savePreviewWidth
    width: grid.horizontalSpacing * 2 +
           (irThumb.visible ? irThumb.width + grid.horizontalSpacing * 2 + 1 : 0) +
           (dcThumb.visible ? dcThumb.width + grid.horizontalSpacing * 2 + 1 : 0) +
           (videoThumb.visible ? videoThumb.width + grid.horizontalSpacing * 2 +1 : 0);

    height: grid.savePreviewHeight + grid.bottomMargin + grid.verticalSpacing
    visible: isVisible && !pogo

    // Timer that makes sure save status is shown at least a minimum amount of time
    Timer {
        id: timer
        interval: timing.savePreviewShowTime
        onTriggered: {
            hideAnimation.start()
        }
    }

    NumberAnimation {
        id: showAnimation
        target: savePreview; property: "y"; to: grid.height - height;
        duration: 200; easing.type: Easing.InOutQuad
    }

    SequentialAnimation {
        id: hideAnimation
        NumberAnimation {
            id: hideAnimationLower
            target: savePreview; property: "y"; to: grid.height;
            duration: 200; easing.type: Easing.InOutQuad
        }
        ScriptAction { script: { isVisible = false } }
    }

    function show() {
        isVisible = true
        showAnimation.start()
        timer.start()
    }

    function hide() {
        if (isVisible) {
            isVisible = false
            timer.stop()
            hideAnimation.start()
        }
    }

    // The background
    RoundedRect {
        id: backgroundImage
        width: savePreview.width
        height: grid.savePreviewHeight

        Rectangle {
            id: irThumb
            width: grid.savePreviewThumbWidth + 1
            height: grid.savePreviewThumbHeight + 1
            anchors.left: backgroundImage.left
            anchors.leftMargin: grid.horizontalSpacing * 2
            anchors.topMargin: grid.verticalSpacing
            y: grid.verticalSpacing * 2
            color: colors.background
            border.color: colors.mediumGrey
            border.width: 1
            visible: greenbox.mediaControl.hasIR

            Image {
                id: thumbIRImage
                x: 1
                y: 1
                width: grid.savePreviewThumbWidth
                height: grid.savePreviewThumbHeight
                source: (isVisible && greenbox.mediaControl.hasIR) ? "image://thumbImageProvider/IR_" + greenbox.mediaControl.thumbCounter : ""
            }
        }

        Rectangle {
            id: dcThumb
            width: grid.savePreviewThumbWidth + 1
            height: grid.savePreviewThumbHeight + 1
            anchors.right: backgroundImage.right
            anchors.rightMargin: grid.horizontalSpacing * 2 + 1
            y: grid.verticalSpacing * 2
            anchors.topMargin: grid.verticalSpacing
            color: colors.background
            border.color: colors.mediumGrey
            border.width: 1
            visible: greenbox.mediaControl.hasDC

            Image {
                id: thumbDCImage
                x: 1
                y: 1
                width: grid.savePreviewThumbWidth
                height: grid.savePreviewThumbHeight
                source: (isVisible && greenbox.mediaControl.hasDC) ? "image://thumbImageProvider/DC_" + greenbox.mediaControl.thumbCounter : ""
            }
        }

        Rectangle {
            id: videoThumb
            width: grid.savePreviewThumbWidth +1
            height: grid.savePreviewThumbHeight +1
            anchors.right: backgroundImage.right
            anchors.rightMargin: grid.horizontalSpacing * 2 + 1
            y: grid.verticalSpacing * 2
            anchors.topMargin: grid.verticalSpacing
            color: colors.background
            border.color: colors.mediumGrey
            border.width: 1
            visible: greenbox.mediaControl.hasVideo

            Image {
                id: thumbVideoImage
                x: 1
                y: 1
                width: grid.savePreviewThumbWidth
                height: grid.savePreviewThumbHeight
                source: (isVisible && greenbox.mediaControl.hasVideo) ? "image://thumbImageProvider/VI_" + greenbox.mediaControl.thumbCounter : ""

                Image{
                    id: videoIndicationOverlay
                    anchors.centerIn: parent
                    source: (greenbox.mediaControl.hasVideo) ? "../images/Sc_Video_Directplay_Def.png" : ""
                    width: grid.savePreviewThumbWidth / 3
                    height: grid.savePreviewThumbWidth / 3
                    smooth: true
                }
            }
        }

        // The text labels
        Text {
            id: savingName
            anchors.horizontalCenter: backgroundImage.horizontalCenter
            anchors.bottom: parent.bottom
            anchors.bottomMargin: grid.verticalSpacing
            font.family: fonts.family
            font.pixelSize: fonts.smallSize
            color: colors.textFocused
            text: greenbox.mediaControl.saveFileNameShort
        }
    }
}
