import QtQuick 1.1

//
// ListView delegate used by SettingsPage
//

//Rectangle {
Item {
    property variant model
    property variant view

    // Expose model data (only components can be aliased)
    property variant delegateNextModel:         model.nextModel
    property string delegateNextQML:            model.nextQML
    property string delegateID:                 model.ID
    property string delegateLabel:              model.label
    property string delegateValue:              model.value
    property string delegateSettingType:        model.settingType
    property bool   delegateSettingRadio:       model.radio
    property bool   delegateSettingCheckBox:    model.checkBox
    property bool   delegateItemEnabled:        model.itemEnabled
    property string delegateConfirmMsg:         model.confirmMsg
    property string delegateConfirmText:        model.confirmText
    property string delegateConfirmIcon:        model.confirmIcon
    property string delegateConfirmCancel:      model.confirmCancel
    property string delegateConfirmOk:          model.confirmOk
    property variant delegateAutoHidePage:      model.autoHidePage !== undefined ? model.autoHidePage : true
    property bool   delegateVisible:            model.visible !== undefined ? model.visible : true

    // Properties used for multi model settings
    property variant delegateNextModels: model.nextModels
    property variant delegateNextModel1: model.nextModel1
    property variant delegateNextModel2: model.nextModel2
    property variant delegateNextModel3: model.nextModel3
    property variant delegateNextModel4: model.nextModel4
    property variant delegateNextModel5: model.nextModel5
    property variant delegateNextModel6: model.nextModel6

    signal clicked()

    id: settingsDelegate

    visible: delegateVisible
    width: view.width
    height: visible ? grid.cellHeight + grid.verticalSpacing : 0

    Image {
        id: iconImage
        anchors.left: parent.left
        anchors.leftMargin: grid.unit*3
        anchors.verticalCenter: parent.verticalCenter
        source: (model.icon === undefined || model.icon === "") ?
                    "" :
                    "../images/" + model.icon + (isCurrentItem ? "_Sel" : "_Def") + ".png"
    }

    Text {
        id: settingTextItem
        anchors.left: parent.left
        anchors.leftMargin: (model.icon !== undefined && model.icon !== "") ? grid.horizontalSpacing * 4 + iconImage.width : grid.unit*5
        anchors.verticalCenter: parent.verticalCenter
        color: model.itemEnabled ? (isCurrentItem ? colors.textFocused : colors.textNormal) : colors.textDisabled
        font.pixelSize: fonts.smallSize
        font.family: model.label !== "" ? fonts.family : (model.specialFont === "" ? fonts.family : model.specialFont)
        text: model.label !== "" ?
                  qsTrId(model.label) + translation.update :
                  (model.translateValue ?
                       (model.value2 === undefined || model.value2 === "" ? qsTrId(model.value) : qsTrId(model.value).arg(model.value2)) + translation.update :
                       model.value + (model.value2 === undefined ? "" : model.value2))
    }

    Image {
        id: checkableImage
        anchors.right: parent.right
        anchors.rightMargin: model.radio || model.checkBox ? 3 * grid.horizontalSpacing : 0
        anchors.verticalCenter: parent.verticalCenter
        source: model.radio ?
                    "../images/Ic_ListChoice_RadioButton" +
                    (model.checked ? "Checked" : "") +
                    (isCurrentItem ? "_Sel.png" : "_Def.png")
                  : (model.checkBox ?
                         "../images/Ic_ListChoice_CheckBox" + (model.checked ? "Checked" : "") +
                         (isCurrentItem ? "_Sel.png" : "_Def.png") : "")
        visible: model.radio || model.checkBox
        width: visible ? source.width : 0
    }

    Image {
        id: arrowImage
        anchors.right: parent.right
        anchors.rightMargin: grid.horizontalSpacing
        anchors.verticalCenter: parent.verticalCenter
        source: "../images/Ic_List_ArrowRight" + (isCurrentItem ? "_Sel.png" : "_Def.png")
        visible: model.nextQML !== "" && ( ! checkableImage.visible)
    }

    Text {
        id: valueTextItem
        // Always align after the arrowImage if the checkableImage is not
        // visible.
        anchors.right: checkableImage.visible ? checkableImage.left : arrowImage.left
        anchors.verticalCenter: parent.verticalCenter
        color: isCurrentItem ? colors.textNormal : colors.textDisabled
        font.pixelSize: fonts.smallSize
        font.family: model.specialFont === "" ? fonts.family : model.specialFont
        text: model.label === "" ?
                  "" : (model.translateValue ?
                            (model.value2 === undefined || model.value2 === "" ? qsTrId(model.value) : qsTrId(model.value).arg(model.value2)) + translation.update :
                            model.value + (model.value2 === undefined ? "" : model.value2))
    }

    // Mouse area for entire delegate
    MouseArea {
        anchors.fill: parent
        onClicked: {
            if (model.itemEnabled)
            {
                view.currentIndex = model.index
                if (model.checkBox === false)
                    settingsDelegate.clicked()
            }
        }

        // For possible future functionality.
        //onPressAndHold: {
        //    view.currentIndex = model.index
        //}
    }

    // Extra mouse area for checkbox delegates
    MouseArea {
        id: checkBoxMouseArea
        anchors.fill: checkableImage
        enabled: checkableImage.visible
        onClicked: {
            if (model.itemEnabled)
            {
                view.currentIndex = model.index
                settingsDelegate.clicked()
            }
        }
    }
}
