import QtQuick 1.1

// Soft keyboard evaluation
import "SoftKeyboard"

//
// TouchCalibration - page where user calibrate the touch screen
//

FocusScope {
    property variant model
    signal focusDesktopFocusGroup

    id: softKeyboardPage

    x: 0
    y: grid.height
    width: grid.width
    height: grid.height

    visible: false
    state: "hide"

    property double topOpacity: 1
    Rectangle {
        color: "black"
        anchors.bottom: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        height: parent.height
        opacity: parent.topOpacity
    }


    states: [
        State {
            name: "show"
            PropertyChanges {
                target: softKeyboardPage
                y: 0
                visible: true
                topOpacity: 1
            }
        }
        ,
        State {
            name: "hide"
            PropertyChanges {
                target: softKeyboardPage
                y: grid.height
                visible: false
                topOpacity: 0
            }
        }
        ,
        State {
            when: (softKeyboardPage.model.row0TotalWeight > 0)
            name: "modelAssigned"
            StateChangeScript {
                 name: "Init"
                 script: keyboard.init();
             }
        }
    ]

    transitions: [
        Transition {
            to: "hide"
            SequentialAnimation {
                // Slide out.
                PropertyAnimation {
                    properties: "y,topOpacity"
                    duration: 200
                    easing.type: Easing.InOutQuad
                }
                // Change visibility.
                PropertyAction {
                    property: "visible"
                }
            }
        }
        ,
        Transition {
            to: "show"
            SequentialAnimation {
                // Change visibility.
                PropertyAction {
                    property: "visible"
                }
                // Slide in.
                PropertyAnimation {
                    properties: "y,topOpacity"
                    duration: 200
                    easing.type: Easing.InOutQuad
                }
            }
        }
    ]


    // Functions used to show and hide pages
    function show () {
        state = "show"
        forceActiveFocus()
    }

    function hide () {
        state = "hide"
        model.keyboardShown = false
        focusDesktopFocusGroup()
    }


    // Key handling
    Keys.onReleased: {
        if (event.key === keys.back) {
            hide()
            event.accepted = true
        }
    }


    // The page itself, and its contents
    Rectangle{
        anchors.fill: parent
        color: "black"

        // Header
        SettingsHeader {
            id: settingsHeader
            setting: model.header
            onClicked: hide()
        }

        property bool keyboardShown: model.keyboardShown
        onKeyboardShownChanged: {
            if (model.keyboardShown === true) {
                parent.show()
            }
            else {
                parent.hide()
            }
        }

        Item {
            id: flickableBase

            anchors.left: parent.left
            anchors.right: parent.right
            anchors.rightMargin: 3
            anchors.leftMargin: 3
            anchors.top: settingsHeader.bottom
            anchors.bottom: keyboard.top

            Flickable {
                id: textEditFlickable
                anchors.fill: parent

                contentWidth: textEditBox.width
                contentHeight: textEditBox.height

                flickableDirection: Flickable.VerticalFlick
                boundsBehavior: Flickable.StopAtBounds

                clip: true

                function ensureVisible(r) {
                    if (contentY >= r.y)
                        contentY = r.y;
                    else if (contentY + height <= r.y + r.height)
                        contentY = r.y + r.height - height;
                }

                TextEdit {
                    id: textEditBox
                    wrapMode: TextEdit.Wrap
                    textFormat: TextEdit.PlainText
                    text: model.textValue
                    onTextChanged: model.textValue = text
                    readOnly: false
                    focus: true

                    color: keyboard.primaryCharacterColor
                    font.pixelSize: fonts.smallSize

                    onCursorRectangleChanged: textEditFlickable.ensureVisible(cursorRectangle)
                }
            }

            // Scroll bar
            Item {
                id: scrollBar
                visible: textEditBox.height > flickableBase.height
                anchors.right: parent.right
                anchors.top: parent.top
                anchors.bottom: parent.bottom
                width: 3

                // Background
                Rectangle {
                    color: "#323232"
                    anchors.fill: parent
                }

                // Foreground
                Rectangle {
                    color: "#0066cc"
                    anchors.right: parent.right
                    width: parent.width
                    height: Math.pow(flickableBase.height, 2) / textEditBox.height
                    y: textEditFlickable.visibleArea.yPosition * flickableBase.height
                }
            }

        }

        Keyboard {
            id: keyboard
            anchors.fill : parent
            anchors.topMargin: parent.height*0.4
            anchors.rightMargin: 3
            anchors.leftMargin: 3
            anchors.bottomMargin: 5
            model: softKeyboardPage.model

            Binding {
                target: keyboard
                property: "textField"
                value: textEditBox
            }
        }

    }

}
