import QtQuick 1.1

Item {
    id: statusBar
    width: row.width
    height: grid.resultTableRowHeight
    visible: (greenbox.system.tilt === 0 || greenbox.system.tilt === 180)

    function getIndex(percent) {
        if(percent < 20)
            return 0;
        else if(percent > 80)
            return 4;
        else
            return (percent / 20);
    }

    RoundedRect {
        anchors.fill: parent
        visible:  (powerStatus.visible || storageStatus.visible || zoomStatus.visible || wifiStatus.visible || bluetoothStatus.visible ||
                   headsetStatus.visible || lampStatus.visible || usbStatus.visible  || emissivity.visible )
    }

    Row {
        id: row
        height: parent.height
        y: -1

        // Power
        Image {
            id: powerStatus
            property int index: getIndex(flirSystem.power)
            source: "../images/Sc_Status_Battery0" + Math.max(index, flirSystem.powerCharging ? 0 : 1) + "_Def.png"
            visible: pogo ? false :
                            flirSystem.powerCharging ? true :
                                                       !menus.menuOpen ? index === 0 : true
            anchors.verticalCenter: parent.verticalCenter
            onIndexChanged: {
                if (index === 0)
                    batteryBlinkTimer.start()
                else if (batteryBlinkTimer.running)
                {
                    batteryBlinkTimer.stop()
                    opacity = 1
                }
            }
            Component.onCompleted: {if (index === 0) batteryBlinkTimer.start() }
        }
        Timer {
            id: batteryBlinkTimer
            interval: 500
            repeat: true
            onTriggered: {
                if (powerStatus.opacity === 1 && !flirSystem.powerCharging)
                    powerStatus.opacity = 0.25
                else
                    powerStatus.opacity = 1
            }
        }

        // Divider
        Image {
            anchors.verticalCenter: parent.verticalCenter
            source: "../images/Bg_Status_Divider_Def.png"
            visible: powerStatus.visible && (storageStatus.visible || zoomStatus.visible || wifiStatus.visible || bluetoothStatus.visible ||
                                             headsetStatus.visible || lampStatus.visible || usbStatus.visible  || emissivity.visible )
        }

        // Storage card
        Image {
            id: storageStatus
            property int index: getIndex(flirSystem.storage)
            source: "../images/Sc_Status_Memcard0" + index + "_Def.png"
            visible: pogo ? false :
                            flirSystem.storageMounted ? (!menus.menuOpen ? index === 4 : true) : false
            anchors.verticalCenter: parent.verticalCenter
        }

        // Divider
        Image {
            anchors.verticalCenter: parent.verticalCenter
            source: "../images/Bg_Status_Divider_Def.png"
            visible: storageStatus.visible && (zoomStatus.visible || wifiStatus.visible || bluetoothStatus.visible ||
                                               headsetStatus.visible || lampStatus.visible || usbStatus.visible  || emissivity.visible )
        }

        // Zoom (visible in pogo)
        Image {
            id: zoomStatus
            source: greenbox.system.zoom > 7 ? "../images/Sc_Status_Zoom8x_Def.png" :
                        greenbox.system.zoom > 3 ? "../images/Sc_Status_Zoom4x_Def.png" :
                            greenbox.system.zoom > 1.0 ? "../images/Sc_Status_Zoom2x_Def.png" : ""
            visible: greenbox.system.zoom > 1.0 ? true : false
            anchors.verticalCenter: parent.verticalCenter
        }

        // Divider
        Image {
            anchors.verticalCenter: parent.verticalCenter
            source: "../images/Bg_Status_Divider_Def.png"
            visible: zoomStatus.visible && (wifiStatus.visible || bluetoothStatus.visible || headsetStatus.visible ||
                                            lampStatus.visible || usbStatus.visible  || emissivity.visible )
        }

        // WiFi
        Image {
            id: wifiStatus
            source: flirSystem.wifiEnabled ? flirSystem.wifiStatusImage : ""
            visible: flirSystem.wifiEnabled && !pogo && menus.menuOpen
            opacity: flirSystem.wifiActive ? 1.0 : 0.25
            anchors.verticalCenter: parent.verticalCenter
        }

        // Divider
        Image {
            anchors.verticalCenter: parent.verticalCenter
            source: "../images/Bg_Status_Divider_Def.png"
            visible: wifiStatus.visible && (bluetoothStatus.visible || headsetStatus.visible || lampStatus.visible || usbStatus.visible || emissivity.visible)
        }

        // Bluetooth
        Image {
            id: bluetoothStatus
            source: flirSystem.bluetoothEnabled ? "../images/Sc_Status_Bluetooth_Def.png" : ""
            opacity: flirSystem.bluetoothActive ? 1.0 : 0.25
            visible: flirSystem.bluetoothEnabled && !pogo  && menus.menuOpen
            anchors.verticalCenter: parent.verticalCenter
        }

        // Divider
        Image {
            anchors.verticalCenter: parent.verticalCenter
            source: "../images/Bg_Status_Divider_Def.png"
            visible: bluetoothStatus.visible && (headsetStatus.visible || lampStatus.visible || usbStatus.visible || emissivity.visible)
        }

        // Headset
        Image {
            id: headsetStatus
            source: flirSystem.headsetActive ? "../images/Sc_Status_BluetoothHeadset_Def.png" : ""
            visible: flirSystem.headsetActive && !pogo  && menus.menuOpen
            anchors.verticalCenter: parent.verticalCenter
        }

        // Divider
        Image {
            anchors.verticalCenter: parent.verticalCenter
            source: "../images/Bg_Status_Divider_Def.png"
            visible: headsetStatus.visible && (lampStatus.visible || usbStatus.visible || emissivity.visible)
        }

        // Lamp
        Image {
            id: lampStatus
            source: "../images/Sc_Status_LampOn_Def.png"
            visible: flirSystem.lampActive && !pogo
            anchors.verticalCenter: parent.verticalCenter
        }

        // Divider
        Image {
            anchors.verticalCenter: parent.verticalCenter
            source: "../images/Bg_Status_Divider_Def.png"
            visible: lampStatus.visible && (usbStatus.visible || emissivity.visible)
        }

        // USB
        Image {
            id: usbStatus
            source: "../images/Sc_Status_Usb_Def.png"
            visible: flirSystem.usbConnected && !pogo
            anchors.verticalCenter: parent.verticalCenter
        }

        // Divider
        Image {
            anchors.verticalCenter: parent.verticalCenter
            source: "../images/Bg_Status_Divider_Def.png"
            visible: usbStatus.visible && emissivity.visible
        }

        // Emissivity (visible in pogo)
        Text {
            id: emissivity
            visible: greenbox.system.emissivityModified
            anchors.verticalCenter: parent.verticalCenter
            text: " " + greenbox.system.emissivity
            font.family: fonts.family
            font.pixelSize: fonts.smallSize
            color: colors.textFocused
        }
    }
}


