import QtQuick 1.1
import System 1.0
import GreenBox 1.0

//! Temperature Scale
//!
//! The scale with the palette gradient on the side of the screen.
//! @ingroup QML

Item {
    id: scaleAndIsothermItem

    // TODO: Compute this some more elaborate way
    width: fonts.smallSize * 2 + grid.horizontalSpacing * 2
    visible: greenbox.appState !== GreenBox.FacetArchiveView

    Component.onCompleted: {
        greenbox.scale.interactive = manualInteraction;
        updateLaserPosDelay.restart()
    }
    onRotationChanged: updateLaserPosDelay.restart()

    // Tilt properties
    rotation: 0
    transformOrigin: Item.TopRight
    state: {
        if (greenbox.system.tilt === 0)
            return "0"
        else if (greenbox.system.tilt === 90)
            return "90"
        else if (greenbox.system.tilt === 180)
            return "180"
        else
            return "270"
    }

    Item {
        id: scaleItem
        anchors.fill: parent
        visible: greenbox.system.viewMode !== System.VIEW_MODE_VISUAL

        // The gradient visualising the scale
        ScaleImage {
            id: scaleGradient
            anchors.right: parent.right
            anchors.top: upperRow.bottom
            anchors.topMargin: grid.verticalSpacing
            anchors.bottom: lowerRow.top
            anchors.bottomMargin: grid.verticalSpacing
            width: grid.horizontalSpacing * 4

            // The visual above color
            Rectangle {
                id: isothermAboveLevel
                anchors.left: scaleGradient.left
                anchors.top: scaleGradient.top
                anchors.right: scaleGradient.right

                height: Math.max(scaleGradient.height - ((scaleGradient.height * greenbox.isotherm.pos ) / 100), 2)

                color: greenbox.isotherm.color
                visible: greenbox.isotherm.type === 1 ||
                         (greenbox.isotherm.type === 5 && greenbox.isotherm.actualType === 1)
            }

            // The visual below color
            Rectangle {
                id: isothermBelowLevel
                anchors.left: scaleGradient.left
                anchors.bottom: scaleGradient.bottom
                anchors.right: scaleGradient.right

                height: Math.max((scaleGradient.height * greenbox.isotherm.pos ) / 100, 2)

                color: greenbox.isotherm.color
                visible: greenbox.isotherm.type === 2 || greenbox.isotherm.type === 4 ||
                         (greenbox.isotherm.type === 5 && greenbox.isotherm.actualType === 2)
            }

            // The visual interval color
            Rectangle {
                id: isothermIntervalLevel
                anchors.left: scaleGradient.left
                anchors.top: scaleGradient.top
                anchors.topMargin: scaleGradient.height - ((scaleGradient.height * greenbox.isotherm.pos ) / 100)
                anchors.right: scaleGradient.right

                height: Math.min((scaleGradient.height * greenbox.isotherm.lowPos ) / 100,
                                 (scaleGradient.height * greenbox.isotherm.pos ) / 100)

                color: greenbox.isotherm.color
                visible: greenbox.isotherm.type === 3
            }

            // Isotherm interaction marker (arrows)
            Image {
                id: arrowsID
                source: y < 0 ? "../images/Sc_Status_ScaleArrowDown_Sel.png" :
                                y > scaleGradient.height - height ? "../images/Sc_Status_ScaleArrowUp_Sel.png" :
                                                                        "../images/Sc_Status_ScaleArrowUpDown_Sel.png"
                visible: greenbox.isotherm.type === 0 ?
                             false :
                             (greenbox.scale.interactionMode === Scale.InteractionObjectIsotherm ||
                              greenbox.scale.interactionMode === Scale.InteractionObjectIsothermMax ||
                              greenbox.scale.interactionMode === Scale.InteractionObjectIsothermMin) ? true : false
                anchors.horizontalCenter: scaleGradient.horizontalCenter
                y: greenbox.scale.interactionMode === Scale.InteractionObjectIsothermMin ?
                       isothermIntervalLevel.y + isothermIntervalLevel.height - height / 2 :
                       Math.min(
                           Math.max(scaleGradient.height - ((scaleGradient.height * greenbox.isotherm.pos ) / 100) - height / 2,
                                -height / 3), scaleGradient.height - 2 * height / 3)
            }

            // Gradient border
            BorderImage {
                anchors.fill: scaleGradient
                anchors.topMargin: -grid.verticalSpacing
                anchors.bottomMargin: -grid.verticalSpacing
                border { left: grid.unit; top: grid.unit; right: grid.unit; bottom: grid.unit }
                source: greenbox.scale.manual?"../images/Bg_Scale_OutlineLocked_Def.png":"../images/Bg_Scale_Outline_Def.png"
            }

            MouseArea {
                id: scaleGradientMouseArea
                anchors.fill: scaleGradient
                anchors.leftMargin: -scaleGradient.width // increase area to accound for poor touch screen calibration
                onPressed: {
                    if (greenbox.scale.interactive)
                    {
                        greenbox.scale.manual = false
                        greenbox.scale.interactive = false
                    }
                    else
                    {
                        greenbox.scale.manual = true
                        greenbox.scale.interactive = true
                    }
                }
            }
        }

        // The background of the upper label
        RoundedRect {
            id: upperRow
            anchors.right: parent.right
            anchors.top: parent.top
            width: upperContent.width + grid.horizontalSpacing * 4
            height: grid.resultTableRowHeight

            Row {
                anchors.centerIn: upperRow
                id: upperContent
                spacing: grid.horizontalSpacing
                height: grid.resultTableRowHeight

                Image {
                    anchors.verticalCenter: parent.verticalCenter
                    visible: !pogo && greenbox.scale.manual
                    width: pogo ? 0 : implicitWidth
                    opacity: (greenbox.scale.interactive === false ||
                              greenbox.scale.interactionMode === Scale.InteractionObjectLevel ||
                              greenbox.scale.interactionMode === Scale.InteractionObjectMax) ? 1 : 0.35
                    source: greenbox.scale.interactive === false ?
                                "../images/Sc_Status_Locked_Def.png" : "../images/Sc_Status_ScaleArrowUpDown_Sel.png"
                }

                // The upper label
                Text {
                    id: upperLabel
                    anchors.verticalCenter: parent.verticalCenter

                    font.family: fonts.latinFamily
                    font.pixelSize: fonts.smallSize
                    font.bold: true
                    color: colors.textFocused
                    opacity: (pogo || greenbox.scale.manual === false ||
                              greenbox.scale.interactive === false ||
                              greenbox.scale.interactionMode === Scale.InteractionObjectLevel ||
                              greenbox.scale.interactionMode === Scale.InteractionObjectMax) ? 1 : 0.35
                    text: greenbox.scale.levelHigh
                }
            }
        }

        // The background of the lower label
        RoundedRect {
            id: lowerRow
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            width: lowerContent.width + grid.horizontalSpacing * 4
            height: grid.resultTableRowHeight

            Row {
                anchors.centerIn: lowerRow
                id: lowerContent
                spacing: grid.horizontalSpacing
                height: grid.resultTableRowHeight

                Image {
                    anchors.verticalCenter: parent.verticalCenter
                    visible: !pogo && greenbox.scale.manual
                    width: pogo ? 0 : implicitWidth
                    opacity: (greenbox.scale.interactive === false ||
                              greenbox.scale.interactionMode === Scale.InteractionObjectLevel ||
                              greenbox.scale.interactionMode === Scale.InteractionObjectMin) ? 1 : 0.35
                    source: greenbox.scale.interactive === false ?
                                "../images/Sc_Status_Locked_Def.png" : "../images/Sc_Status_ScaleArrowUpDown_Sel.png"
                }

                // The lower label
                Text {
                    id: lowerLabel
                    anchors.verticalCenter: parent.verticalCenter

                    font.family: fonts.latinFamily
                    font.pixelSize: fonts.smallSize
                    font.bold: true
                    color: colors.textFocused
                    opacity: (pogo || greenbox.scale.manual === false ||
                              greenbox.scale.interactive === false ||
                              greenbox.scale.interactionMode === Scale.InteractionObjectLevel ||
                              greenbox.scale.interactionMode === Scale.InteractionObjectMin) ? 1 : 0.35
                    text: greenbox.scale.levelLow
                }
            }
        }
    }

    // The isotherm indicator
    RoundedRect {

        id: isotherm
        anchors.top: parent.top
        x: scaleItem.visible ? parent.width - width - upperRow.width - grid.horizontalSpacing : parent.width - width

        width: isothermContent.width + grid.horizontalSpacing * 4
        height: isothermContent.height

        visible: greenbox.isotherm.type === 0 ? false : greenbox.system.viewMode === System.VIEW_MODE_VISUAL ? false : true

        // Isotherm value(s)
        Row {
            id: isothermContent
            spacing: grid.horizontalSpacing
            height: grid.resultTableRowHeight
            anchors.centerIn: isotherm

            Rectangle {
                anchors.verticalCenter: parent.verticalCenter
                color: greenbox.isotherm.color
                width: 10;
                height: 10
            }

            Text {
                anchors.verticalCenter: parent.verticalCenter
                font.family: fonts.latinFamily
                font.pixelSize: fonts.smallSize
                color: colors.textFocused
                opacity: (greenbox.scale.interactionMode === Scale.InteractionObjectIsotherm ||
                          greenbox.scale.interactionMode === Scale.InteractionObjectIsothermMin) ? 1 : 0.35
                text: {
                    if (greenbox.isotherm.type === 1)
                        return "> " + greenbox.isotherm.level
                    else if (greenbox.isotherm.type === 2)
                        return "< " + greenbox.isotherm.level
                    else if (greenbox.isotherm.type === 3)
                        return greenbox.isotherm.lowLevel + (greenbox.scale.interactionMode === Scale.InteractionObjectIsothermMax ? " - " : "")
                    else if (greenbox.isotherm.type === 4)
                        return "< " + greenbox.isotherm.level
                    else if (greenbox.isotherm.type === 5)
                    {
                        if (greenbox.isotherm.actualType === 1)
                            return "> " + greenbox.isotherm.level
                        else
                            return "< " + greenbox.isotherm.level
                    }
                    else
                        return ""       // Default to avoid warnings during startup
                }
            }

            Text {
                anchors.verticalCenter: parent.verticalCenter
                font.family: fonts.latinFamily
                font.pixelSize: fonts.smallSize
                color: colors.textFocused
                opacity: (greenbox.scale.interactionMode === Scale.InteractionObjectIsothermMax) ? 1 : 0.35
                visible: greenbox.isotherm.type === 3 ? true : false
                text: (greenbox.scale.interactionMode === Scale.InteractionObjectIsothermMax ? "" : " - ") + greenbox.isotherm.level
            }
        }
    }

    // Tilt states
    states: [
        State {
            name: "0"
            PropertyChanges { target: scaleAndIsothermItem; rotation: 0 }
            PropertyChanges { target: scaleAndIsothermItem; height: grid.height - grid.topMargin - grid.bottomMargin - 2 * grid.verticalSpacing }
            PropertyChanges { target: scaleAndIsothermItem; x: grid.width - grid.rightMargin - grid.irRightMargin - grid.horizontalSpacing - width }
            PropertyChanges { target: scaleAndIsothermItem; y: grid.topMargin + grid.verticalSpacing }
        },
        State {
            name: "90"
            PropertyChanges { target: scaleAndIsothermItem; rotation: 90 }
            PropertyChanges { target: scaleAndIsothermItem; height: grid.width - grid.leftMargin - grid.irLeftMargin - grid.rightMargin - grid.irRightMargin - 2 * grid.horizontalSpacing }
            PropertyChanges { target: scaleAndIsothermItem; x: height - width + grid.leftMargin + grid.irLeftMargin + grid.horizontalSpacing }
            PropertyChanges { target: scaleAndIsothermItem; y: grid.height - grid.bottomMargin - grid.verticalSpacing }
        },
        State {
            name: "180"
            PropertyChanges { target: scaleAndIsothermItem; rotation: 180 }
            PropertyChanges { target: scaleAndIsothermItem; height: grid.height - grid.topMargin - grid.bottomMargin - 2 * grid.verticalSpacing }
            PropertyChanges { target: scaleAndIsothermItem; x: grid.leftMargin + grid.irLeftMargin + grid.horizontalSpacing - width }
            PropertyChanges { target: scaleAndIsothermItem; y: grid.height - grid.verticalSpacing - grid.topMargin }
        },
        State {
            name: "270"
            PropertyChanges { target: scaleAndIsothermItem; rotation: 270 }
            PropertyChanges { target: scaleAndIsothermItem; height: grid.width - grid.leftMargin - grid.irLeftMargin - grid.rightMargin - grid.irRightMargin - 2 * grid.horizontalSpacing }
            PropertyChanges { target: scaleAndIsothermItem; x: grid.leftMargin + grid.irLeftMargin + grid.horizontalSpacing - width }
            PropertyChanges { target: scaleAndIsothermItem; y: grid.topMargin + grid.verticalSpacing }
        }
    ]


    Image{
        id: laserOnIndicatorPlaceholder
        source: "../images/Sc_Status_Laser.png"
        anchors.top: parent.top
        visible: false

        x: {
                updateLaserPosDelay.restart()

                if (greenbox.appState !== GreenBox.FacetLiveView && greenbox.appState !== GreenBox.FacetMediaControlState)
                    return grid.width - laserOnIndicatorPlaceholder.sourceSize.width - grid.horizontalSpacing;
                else if(isotherm.visible)
                    return isotherm.x - laserOnIndicatorPlaceholder.sourceSize.width - grid.horizontalSpacing
                else if(scaleItem.visible)
                    return upperRow.x - laserOnIndicatorPlaceholder.sourceSize.width - grid.horizontalSpacing
                else
                    return parent.width - laserOnIndicatorPlaceholder.sourceSize.width
        }

        Timer{
            id:updateLaserPosDelay
            interval: 50
            repeat: false
            onTriggered: laserOnIndicatorPlaceholder.updateLaserPlaceHolder()

        }

        function updateLaserPlaceHolder()
        {
            var laserIndicatorElement = greenbox.GetNamedObject("laserOnIndicator")
            var coordReference = (greenbox.appState === GreenBox.FacetLiveView
                    || greenbox.appState === GreenBox.FacetMediaControlState) ?  scaleAndIsothermItem : root

            laserIndicatorElement.updateLocation(coordReference, laserOnIndicatorPlaceholder)
         }

    }

//    // Tilt transitions
//    transitions: [
//        Transition {
//            ParallelAnimation{
//                PropertyAnimation { target: scaleAndIsothermItem; properties: "x";
//                                    duration: 200; easing.type: Easing.OutQuad }
//                PropertyAnimation { target: scaleAndIsothermItem; properties: "y";
//                                    duration: 200; easing.type: Easing.OutQuad }
//                PropertyAnimation { target: scaleAndIsothermItem; properties: "rotation";
//                                    duration: 200; easing.type: Easing.OutQuad }
//            }
//        }
//    ]
}
