import QtQuick 1.1
import se.flir 1.0

// ThumbnailDelegate
// -----------------
// Delegate for the ThumbnailArchive element.

Item {

    // Property values

    id: thumbnailDelegate
    width: grid.archiveCellWidth
    height: grid.archiveCellHeight

    // The "stack"

    Image {
        x: grid.horizontalSpacing * 3
        y: grid.verticalSpacing *2
        source: "../images/Bg_ArchiveViewThumb_Group" +
                (groupSize === 2 ? "02" : "03") + (thumbnailDelegate.GridView.isCurrentItem ? "_Sel.png" : "_Def.png")
        visible: groupSize > 1
    }

    // The thumbnail image

    Image {
        id: thumbnail
        x: grid.horizontalSpacing * 2
        y: grid.verticalSpacing * 4
        width: grid.thumbnailWidth
        height: grid.thumbnailHeight
        sourceSize.width: grid.thumbnailWidth
        sourceSize.height: grid.thumbnailHeight
//        asynchronous: true
        cache: false
        source: "image://archiveImageProvider/thumb_" + currentPrimaryImageKey + "_" + thumbVersion

        BorderImage {
            anchors.fill: parent
            asynchronous: false
            cache: true
            border { left: 5; top: 5; right: 5; bottom: 5 }
            source: thumbnail.status === Image.Ready ?
                        "../images/Bg_ArchiveViewThumb_ImgOutline_" + (thumbnailDelegate.GridView.isCurrentItem ? "Sel.png" : "Def.png") :
                        (thumbnail.status === Image.Loading ?
                             "../images/Bg_ArchiveViewThumb_ImgNotLoaded_Def.png" :
                             "../images/Bg_ArchiveViewThumb_ImgNotFound_Def.png")
        }

        Image {
            id: videoIndicationOverlay
            visible: groupModel.itemType === ArchiveGroupModel.ITEM_TYPE_VIDEO
            anchors.centerIn: parent
            source: groupModel.itemType === ArchiveGroupModel.ITEM_TYPE_VIDEO ? "../images/Sc_Video_DirectplayThumb_Def.png" : ""
        }
    }


    // The file / group name

    Text {
        anchors.left: thumbnail.left
        anchors.right: thumbnail.right
        anchors.top: thumbnail.bottom
        anchors.bottom: parent.bottom
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        elide: Text.ElideMiddle
        font.family: fonts.family
        font.pixelSize: fonts.smallSize
        color: thumbnailDelegate.GridView.isCurrentItem ?
                   colors.textFocused : colors.textNormal
        text: groupName
    }

    // Touch handling

    MouseArea {
        anchors.fill: parent
        onClicked: {
            if (parent.GridView.view.currentIndex === index) {
                showPreviewArchive()
            } else {
                parent.GridView.view.currentIndex = index
            }
        }
    }
}
