import QtQuick 1.1

//
// TouchCalibration - page where user calibrate the touch screen
//

Item {
    property Item previous
    property string name: "Touch calibration page"
    property string basePage: ""                // Needed for general purpose compability
    property variant model: undefined           // Needed for general purpose compability
    property int calibState: greenbox.touchCalibration.state
    signal hideSignal

    id: page
    x: grid.width
    y: 0
    width: grid.width
    height: grid.height
    opacity: 1

    // Animations used to slide pages in and out

    ParallelAnimation {
        id: showAnimation
        NumberAnimation {
            target: page; property: "x"; to: previous === null ? 0 : grid.width;
            duration: previous !== null ? 200 : 0; easing.type: Easing.InOutQuad
        }
        ScriptAction { script: { if (previous !== null) {previous.runHideParentAnimation() } } }
    }

    NumberAnimation {
        id: hideParentAnimation
        target: page; property: "x"; to: previous === null ? -grid.width : 0;
        duration: 200; easing.type: Easing.InOutQuad
    }

    NumberAnimation {
        id: showParentAnimation
        target: page; property: "x"; to: previous === null ? 0 : grid.width;
        duration: 200; easing.type: Easing.InOutQuad
    }

    SequentialAnimation {
        id: hideAnimation
        ParallelAnimation {
            NumberAnimation {
                target: page; property: "x"; to: grid.width;
                duration: previous !== null ? 200 : 0; easing.type: Easing.InOutQuad
            }
            ScriptAction { script: { if (previous !== null) { previous.runShowParentAnimation();} } }
        }
        ScriptAction { script: { if (previous !== null) {previous.forceActiveFocus(); } hideSignal() } }
    }

    // Functions needed to access animations in parent

    function runShowParentAnimation() { showParentAnimation.start() }
    function runHideParentAnimation() { hideParentAnimation.start() }

    // Functions used to show and hide pages

    function show ()
    {
        showAnimation.start()
        forceActiveFocus()
    }

    function hide ()
    {
        hideAnimation.start()
    }

    // Key handling
    Keys.onPressed: {
        event.accepted = true
    }

    Keys.onReleased: {
        if (event.key === keys.back)
        {
            hide()
            event.accepted = true
        }
        else
            event.accepted = true
    }

    // The page itself, and its contents

    Rectangle {
        anchors.fill: parent
        color: "black"

        // Cross hair
        Image {
            x: greenbox.touchCalibration.markerX - width / 2
            y: greenbox.touchCalibration.markerY - height / 2
            source: "../images/Sc_MeasureToolPlaced_Spot_Def.png"
        }

        MouseArea {
            anchors.fill: parent
            onClicked: {
                greenbox.touchCalibration.setPosition(mouseX, mouseY)
            }
        }

        Text {
            //: Instruction on how to calibrate the touch screen.
            //% "Tap the crosshair"
            text: qsTrId("ID_TOUCH_CALIBRATION_INSTRUCTION") + translation.update
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: - parent.height / 4
            color: colors.mediumGrey
            font.pixelSize: fonts.smallSize
            font.family: fonts.family
        }
    }

    onCalibStateChanged: {
        if (calibState > 0)
            messageLoader.source = "MessageBox.qml"
    }

    Loader {
        id: messageLoader
        onLoaded: {
            //: Message header displayed when calibration of touch screen was successful
            //% "Touchscreen calibration"
            item.title = qsTrId("ID_TOUCH_CALIBRATION_MSG_HEADER") + translation.update
            if (calibState === 1)
            {
                //: Message text displayed when calibration of touch screen was successful
                //% "The touchscreen calibration was successful."
                item.text = qsTrId("ID_TOUCH_CALIBRATION_MSG_SUCCESS") + translation.update
            }
            else
            {
                //: Message text displayed when calibration of touch screen was successful
                //% "The touchscreen calibration was not successful."
                item.text = qsTrId("ID_TOUCH_CALIBRATION_MSG_FAILED") + translation.update
            }
            item.hasButtons = false
            item.iconStyle = item.iconEnum.info
            item.show()
            item.forceActiveFocus()
        }
    }

    Connections {
        target: messageLoader.item
        onOkSelected: {
            messageLoader.source = ""
            if (calibState === 1)
                hide()
            greenbox.touchCalibration.state = 0
        }
    }

    Connections {
        target: messageLoader.item
        onCancelSelected: {
            messageLoader.source = ""
            if (calibState === 1)
                hide()
            greenbox.touchCalibration.state = 0
        }
    }
}
