// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1

Item {
    id: valueSelector

    property int numberOfRows: 4 // TODO: this should probably be camera dependent, right?
    property alias model: settingsView1.model
    property alias model2: settingsView2.model
    property int nextModels: 1
    property bool avoidInitialInvoke1: true
    property bool avoidInitialInvoke2: true
    property Item parentToolbarItem: null

    width: grid.cellWidth
    height:  numberOfRows * grid.cellHeight + (numberOfRows - 1) * grid.verticalSpacing

    function setCurrentIndex() {
        if (nextModels === 2)
            avoidInitialInvoke2 = true
        settingsView1.setCurrentIndex()
        if (nextModels === 2)
            settingsView2.setCurrentIndex()
    }

    function show ()
    {
        forceActiveFocus()
        settingsView1.forceActiveFocus()
    }

    function clickHide()
    {
        if (model.invokeOnCurrent === false)
            invokeCurrent()
        hide()
        if (parentToolbarItem !== null)
            parentToolbarItem.forceActiveFocus()
    }

    function hide() {
        if (parent !== null)
            parent.hide()
    }

    function hideAndActivate() {
        if (parent !== null)
            parent.hideAndActivate()
    }

    function invokeCurrent () {
        if (model.invokeOnCurrent === false)
        {
            if (avoidInitialInvoke1 === false)
                model.setProperty(settingsView1.currentIndex, settingsView1.model.modelID, settingsView1.currentItem.delegateValue)
            if (avoidInitialInvoke2 === false && nextModels === 2)
                model2.setProperty(settingsView2.currentIndex, settingsView2.model.modelID, settingsView2.currentItem.delegateValue)
            hideAndActivate()
        }
        else
        {
            hideAndActivate()
        }
    }

    function focusCurrent() {
        if (model.invokeOnCurrent)
        {
            if (avoidInitialInvoke1 === false)
            {
                if (avoidInitialInvoke2 === false || nextModels === 1)
                {
                    model.setProperty(settingsView1.currentIndex, settingsView1.model.modelID, settingsView1.currentItem.delegateValue)
                    if (nextModels === 2)
                        model2.setProperty(settingsView2.currentIndex, settingsView2.model.modelID, settingsView2.currentItem.delegateValue)
                }
                else
                    avoidInitialInvoke2 = false
            }
            else
                avoidInitialInvoke1 = false
        }
        else
        {
            avoidInitialInvoke1 = false
            avoidInitialInvoke2 = false
        }
    }

    function focusChild() { // Used when loaded as stand alone dialog
        settingsView1.forceActiveFocus()
    }

    MouseArea {
        anchors.fill: parent
        onClicked: {
            if (settingsView1.activeFocus === false && settingsView2.activeFocus === false)
                settingsView1.forceActiveFocus()
        }
    }

    BorderImage {
        width: valueSelector.width
        height: valueSelector.height
        border { left: 10; top: 10; right: 10; bottom: 10 }
        source: "../images/Bg_MenuHorizontalMain_Bar_Def.png"
    }

    // Just a dummy text to please the ValueSelectorList... TODO: fix!
    Text {
        id: footerText
        visible: false
    }

    Item {
        id: listHighLight
        anchors.verticalCenter: parent.verticalCenter
        width: grid.unit + grid.cellWidth
        height: valueSelector.height
        x: settingsView1.x

        // Up arrow
        Image {
            anchors.top: parent.top
            anchors.horizontalCenter: parent.horizontalCenter
            source: "../images/Ic_List_ArrowUp_Sel.png"

            MouseArea {
                anchors.fill: parent
                onPressed: {
                    settingsView1.decrementCurrentIndex()
                }
            }
        }

        // Down arrow
        Image {
            anchors.bottom: parent.bottom
            anchors.horizontalCenter: parent.horizontalCenter
            source: "../images/Ic_List_ArrowDown_Sel.png"

            MouseArea {
                anchors.fill: parent
                onPressed: {
                    settingsView1.incrementCurrentIndex()
                }
            }
        }
    }

    Row {
        anchors.top: valueSelector.top
        anchors.topMargin:  grid.cellHeight
        anchors.bottom: valueSelector.bottom
        anchors.bottomMargin:  grid.cellHeight
        anchors.left: valueSelector.left
        width: valueSelector.width

        ValueSelectorList {
            id: settingsView1
            height: parent.height
            width: valueSelector.width / nextModels
        }

        Text {
            text: "-"
            font.family: fonts.family
            font.pixelSize: fonts.smallSize
            color: colors.textNormal
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: -5
            visible: nextModels === 2 ? true : false
        }

        ValueSelectorList {
            id: settingsView2
            visible: nextModels === 2 ? true : false
            height: parent.height
            width: valueSelector.width / nextModels
        }
    }

    // Catch stray keys when the list reaches one end
    Keys.onPressed: {
        if (event.key === keys.down || event.key === keys.up)
            event.accepted = true
        else if (event.key === keys.left)
        {
            if (nextModels == 2 && settingsView2.activeFocus)
                settingsView1.forceActiveFocus()
            event.accepted = true
        }
        else if (event.key === keys.right)
        {
            if (nextModels == 2 && settingsView1.activeFocus)
                settingsView2.forceActiveFocus()
            event.accepted = true
        }
    }

    // Key handling
    Keys.onReleased: {
        if (event.key === keys.select)
        {
            if (model.invokeOnCurrent === false)
                invokeCurrent()
            hide()
            if (parentToolbarItem !== null)
                parentToolbarItem.forceActiveFocus()
            event.accepted = true
        }
        else if (event.key === keys.back)
        {
            hide()
            if (parentToolbarItem !== null)
                parentToolbarItem.forceActiveFocus()
            event.accepted = true
        }
        else if (event.key === keys.left || event.key === keys.right)
        {
            event.accepted = true
        }
    }
}
