import QtQuick 1.1

ListView {

    anchors.verticalCenter: parent.verticalCenter
    anchors.verticalCenterOffset: -2 * grid.verticalSpacing
    height: grid.cellHeight
    width: grid.width / nextModels
    clip: true

    spacing: grid.horizontalSpacing

    boundsBehavior: Flickable.StopAtBounds
    highlightMoveDuration: 1

    preferredHighlightBegin: (height - grid.cellHeight + 3 * grid.verticalSpacing) / 2
    preferredHighlightEnd: (height + grid.cellHeight - 3 * grid.verticalSpacing) / 2
    highlightRangeMode: ListView.StrictlyEnforceRange

    property int storedIndex: 0

    function setCurrentIndex ()
    {
        currentIndex = model.getCurrentIndex()
        storedIndex = currentIndex
    }

    delegate: Rectangle {

        id: delegateID
        property string delegateValue: value
        property string delegateID: ID
        property string delegateLabel: label
        height: grid.cellHeight - 3 * grid.verticalSpacing
        width: grid.width - 2 * grid.cellWidth
        color: "black"
        anchors.horizontalCenter: parent.horizontalCenter

        Text {
            id: delegateText
            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: label === "" ? parent.horizontalCenter : undefined
            anchors.horizontalCenterOffset: label === "" ? 2 : 0
            anchors.right: label === "" ? undefined : parent.right

            text: value2 === undefined ? qsTrId(value) : qsTrId(value).arg(value2)
            color: parent.ListView.isCurrentItem ? (parent.activeFocus ? colors.textFocused : colors.textNormal) : colors.textDisabled
            font.pixelSize: fonts.smallSize
            font.family: fonts.family

            Behavior on color {
                ColorAnimation { duration: 50 }
            }
        }
        Text {
            id: delegateLabel
            visible: label === "" ? false : true
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
            //anchors.horizontalCenterOffset: 2

            text: qsTrId(label)
            color: parent.ListView.isCurrentItem ? (parent.activeFocus ? colors.textFocused : colors.textNormal) : colors.textDisabled
            font.pixelSize: fonts.smallSize
            font.family: fonts.family

            Behavior on color {
                ColorAnimation { duration: 50 }
            }
        }
        MouseArea {
            anchors.fill: delegateID
            onClicked: {
                //console.log("delegate.MouseArea.onPressed")
                if (parent.ListView.view.currentIndex === index)
                {
                    if (parent.activeFocus === false)
                        parent.forceActiveFocus()
                    else
                        clickHide()
                }
                else
                {
                    parent.ListView.view.currentIndex = index
                }

                if (parent.activeFocus === false)
                    parent.forceActiveFocus()
            }
        }
    }

    onFlickEnded: {
        //console.log("flick done: ")
        focusCurrent()
    }

    onCurrentIndexChanged: {
        //console.log("currentIndex changed. Flicking: " + flicking)
        if (!flicking) {
            focusCurrent()
        }
    }

    onActiveFocusChanged: {
        //console.log("list focus changed: " + focus)
        if (focus)
        {
            height = parent.height
            listHighLight.x = x + ((width - grid.cellWidth)/ 2)
        }
        else
            height = grid.cellHeight
        highlightMoveDuration = 250
    }

    // Bind the model tooltip to footer text field (to reflect changes in tooltip)

    Binding {
        target: footerText
        property: "text"
        value: model === undefined ? "" : qsTrId(model.tooltip) + translation.update
        when: (activeFocus || focus) && model !== null
    }

    Keys.onReleased: {
        // Prevent leaking of key events to parent control
        if (event.key === keys.up || event.key === keys.down)
            event.accepted = true
    }
}
