import QtQuick 1.1

//
// ValueSelectorPage - page where user can scroll 1-6 value spin wheels. (Contains some "set date/time" specific code.)
//

Item {
    property Item previous
    property string name: "my second setting"
    property int nextModels: 1
    property alias model1: settingsView1.model
    property alias model2: settingsView2.model
    property alias model3: settingsView3.model
    property alias model4: settingsView4.model
    property alias model5: settingsView5.model
    property alias model6: settingsView6.model
    property alias basePage: header.basePage
    property bool returnStateArchive: false
    signal hideSignal

    id: page
    x: grid.width
    y: 0
    width: grid.width
    height: grid.height
    opacity: 1

    // Animations used to slide pages in and out

    ParallelAnimation {
        id: showAnimation
        NumberAnimation {
            target: page; property: "x"; to: previous === null ? 0 : grid.width;
            duration: previous !== null ? 200 : 0; easing.type: Easing.InOutQuad
        }
        ScriptAction { script: { if (previous !== null) {previous.runHideParentAnimation() } } }
    }

    NumberAnimation {
        id: hideParentAnimation
        target: page; property: "x"; to: previous === null ? -grid.width : 0;
        duration: 200; easing.type: Easing.InOutQuad
    }

    NumberAnimation {
        id: showParentAnimation
        target: page; property: "x"; to: previous === null ? 0 : grid.width;
        duration: 200; easing.type: Easing.InOutQuad
    }

    SequentialAnimation {
        id: hideAnimation
        ParallelAnimation {
            NumberAnimation {
                target: page; property: "x"; to: grid.width;
                duration: previous !== null ? 200 : 0; easing.type: Easing.InOutQuad
            }
            ScriptAction { script: { if (previous !== null) { previous.runShowParentAnimation();} } }
        }
        ScriptAction { script: { if (previous !== null) {previous.forceActiveFocus(); } hideSignal() } }
    }

    // Functions needed to access animations in parent

    function runShowParentAnimation() { showParentAnimation.start() }
    function runHideParentAnimation() { hideParentAnimation.start() }

    // Functions used to show and hide pages
    function show ()
    {
        showAnimation.start()
        forceActiveFocus()
        settingsView1.forceActiveFocus()
        returnStateArchive = false
    }

    function hide ()
    {
        hideAnimation.start()
    }

    // Compatibility with ValueSelectTool
    function clickHide()
    {
        invokeCurrent()
        hide()
    }

    // Escape settings mode entirely
    function hideAll()
    {
        hideSignal()
        while(previous !== null)
        {
            previous.returnStateArchive = returnStateArchive
            if (previous.previous === null)
            {
                previous.forceActiveFocus()
                previous.hide()
            }
            else
            {
                previous.hideSignal()
            }
            previous = previous.previous
        }
    }

    function focusCurrent() {
        // Called by ValueSelectorList.qml when a new item is in focus.
    }

    function invokeCurrent ()
    {
        if (nextModels == 1)
        {
            model1.setProperty(settingsView1.currentIndex, settingsView1.model.modelID, settingsView1.currentItem.delegateValue)
        }
        else
        {
            if (settingsView2.model.modelID === "YEAR")
            {
                model2.setProperties(settingsView2.model.modelID,
                                     settingsView2.currentItem.delegateValue,
                                     settingsView3.currentItem.delegateValue,
                                     settingsView4.currentItem.delegateValue,
                                     settingsView5.currentIndex,
                                     settingsView6.currentItem.delegateValue,
                                     settingsView1.currentItem.delegateValue,
                                     "")
            }
            else
            {
                model1.setProperty(settingsView1.currentIndex, settingsView1.currentItem.delegateID, settingsView1.currentItem.delegateValue)
                if (nextModels > 1)
                    model2.setProperty(settingsView2.currentIndex, settingsView2.currentItem.delegateID, settingsView2.currentItem.delegateValue)
                if (nextModels > 2)
                    model3.setProperty(settingsView3.currentIndex, settingsView3.currentItem.delegateID, settingsView3.currentItem.delegateValue)
                if (nextModels > 3)
                    model4.setProperty(settingsView4.currentIndex, settingsView4.currentItem.delegateID, settingsView4.currentItem.delegateValue)
                if (nextModels > 4)
                    model5.setProperty(settingsView5.currentIndex, settingsView5.currentItem.delegateID, settingsView5.currentItem.delegateValue)
                if (nextModels > 5)
                    model6.setProperty(settingsView6.currentIndex, settingsView6.currentItem.delegateID, settingsView6.currentItem.delegateValue)
            }
        }
        hide()

        if (settingsView1.model.modelID === "CUSTOM_EMISSIVITY" ||
            settingsView1.model.modelID === "EMISSIVITY_MATERIAL")
            previous.hide()
    }

    function setCurrentIndex ()
    {
        settingsView1.setCurrentIndex()
        if (nextModels > 1)
            settingsView2.setCurrentIndex()
        if (nextModels > 2)
            settingsView3.setCurrentIndex()
        if (nextModels > 3)
            settingsView4.setCurrentIndex()
        if (nextModels > 4)
            settingsView5.setCurrentIndex()
        if (nextModels > 5)
            settingsView6.setCurrentIndex()
    }

    // Timers
    Timer {
        id: hideTimer
        interval: 300
        onTriggered: { hide() }
    }

    Timer {
        id: escapeSettingsModeTimer
        interval: 1000
        onTriggered: hideAll()
    }

    // Key handling
    Keys.onPressed: {
        event.accepted = true
        if (event.key === keys.back)
        {
            if (event.isAutoRepeat === false && escapeSettingsModeTimer.running === false)
                escapeSettingsModeTimer.start()
        }
        else if (event.key === keys.onOff)
        {
            hideAll()
        }
    }

    Keys.onReleased: {
        if (event.key === keys.back)
        {
            if (event.isAutoRepeat === false)
            {
                if (escapeSettingsModeTimer.running)
                {
                    escapeSettingsModeTimer.stop()
                    hide()
                }
            }
            event.accepted = true
        }
        else if (event.key === keys.select)
        {
            invokeCurrent()
            event.accepted = true
        }
        else if (event.key === keys.archive)
        {
            returnStateArchive = true
            hideAll()
        }
    }

    // Focus change

    onActiveFocusChanged: {
        if (activeFocus)
            show()
    }

    // The page itself, and its contents

    Rectangle {
        anchors.fill: parent
        color: "black"

        MouseArea {
            anchors.fill: parent
            onClicked: {
                //console.log("Rectangle.MouseArea.onClicked")
            }
        }

        // Dialog header

        SettingsHeader {
            id: header
            setting: name
            onClicked: {
                //console.log("SettingsHeader - onClicked")
                hide()
            }
        }

        // List highlight / cursor

        Item {
            id: listHighLight
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: -grid.verticalSpacing
            width: grid.unit + grid.cellWidth
            height: parent.height - 2 * grid.cellHeight - 6 * grid.verticalSpacing
            x: settingsView1.x + ((settingsView1.width - grid.cellWidth)/ 2)

            // Up arrow
            Item {
                anchors.top: parent.top
                anchors.horizontalCenter: parent.horizontalCenter

                Image {
                    visible: upArrowMouseArea.pressed
                    anchors.horizontalCenter: upArrow.horizontalCenter
                    anchors.top: parent.top
                    anchors.topMargin: -5
                    source: "../images/Bg_MenuHorizontalMain_Marker_Foc.png"
                }

                Image {
                    id: upArrow
                    anchors.horizontalCenter: parent.horizontalCenter
                    source: "../images/Ic_List_ArrowUp_Sel.png"
                }

                MouseArea {
                    id: upArrowMouseArea
                    anchors.fill: upArrow
                    onPressed: upArrowTapRepeat.start()
                    onReleased: upArrowTapRepeat.stop()
                }

                Timer {
                    id: upArrowTapRepeat
                    interval: 100
                    repeat: true
                    triggeredOnStart: true
                    onTriggered: {
                        if (settingsView1.focus)
                            settingsView1.decrementCurrentIndex()
                        else if (settingsView2.focus)
                            settingsView2.decrementCurrentIndex()
                        else if (settingsView3.focus)
                            settingsView3.decrementCurrentIndex()
                        else if (settingsView4.focus)
                            settingsView4.decrementCurrentIndex()
                        else if (settingsView5.focus)
                            settingsView5.decrementCurrentIndex()
                        else if (settingsView6.focus)
                            settingsView6.decrementCurrentIndex()
                    }
                }
            }

            // Down arrow
            Item {
                anchors.bottom: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter

                Image {
                    visible: downArrowMouseArea.pressed
                    anchors.horizontalCenter: downArrow.horizontalCenter
                    anchors.bottom: parent.bottom
                    source: "../images/Bg_MenuHorizontalMain_Marker_Foc.png"
                }

                Image {
                    id: downArrow
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.bottom: parent.bottom
                    source: "../images/Ic_List_ArrowDown_Sel.png"
                }

                MouseArea {
                    id: downArrowMouseArea
                    anchors.fill: downArrow
                    onPressed: downArrowTapRepeat.start()
                    onReleased: downArrowTapRepeat.stop()
                }

                Timer {
                    id: downArrowTapRepeat
                    interval: 100
                    repeat: true
                    triggeredOnStart: true
                    onTriggered: {
                        if (settingsView1.focus)
                            settingsView1.incrementCurrentIndex()
                        else if (settingsView2.focus)
                            settingsView2.incrementCurrentIndex()
                        else if (settingsView3.focus)
                            settingsView3.incrementCurrentIndex()
                        else if (settingsView4.focus)
                            settingsView4.incrementCurrentIndex()
                        else if (settingsView5.focus)
                            settingsView5.incrementCurrentIndex()
                        else if (settingsView6.focus)
                            settingsView6.incrementCurrentIndex()
                    }
                }
            }

            // Sideways animation
            Behavior on x {
                NumberAnimation { duration: 50 }
            }
        }

        // Row of lists

        Row {
            id: listRow
            width: grid.width
            anchors.top: header.bottom
            anchors.topMargin: grid.cellHeight
            anchors.bottom: footerText.top
            anchors.bottomMargin: grid.cellHeight

            ValueSelectorList {
                id: settingsView1
                height: listRow.height
                KeyNavigation.left: settingsView1
                KeyNavigation.right: nextModels > 1 ? settingsView2 : settingsView1

                onCurrentIndexChanged: {
                    if (model.modelID === "TIMEZONE")
                    {

                        model.setTZTime(settingsView2.storedIndex, settingsView3.storedIndex, settingsView4.storedIndex,
                                        settingsView5.storedIndex, settingsView6.storedIndex, currentItem.delegateValue)
                        settingsView2.currentIndex = model.getTZAdjustedYearIndex()
                        settingsView3.currentIndex = model.getTZAdjustedMonthIndex()
                        settingsView4.currentIndex = model.getTZAdjustedDayIndex()
                        settingsView5.currentIndex = model.getTZAdjustedHourIndex()
                        settingsView6.currentIndex = model.getTZAdjustedMinuteIndex()
                    } else if (model.modelID == "EMISSIVITY_MATERIAL") {
                        model.setCurrentIndex(currentIndex)
                    }
                }
                onActiveFocusChanged: {
                    if (focus)
                    {
                        if (model.modelID === "TIMEZONE")
                        {
                            model.setLastTimeZone(currentItem.delegateValue);
                            settingsView2.storedIndex = settingsView2.currentIndex;
                            settingsView3.storedIndex = settingsView3.currentIndex;
                            settingsView4.storedIndex = settingsView4.currentIndex;
                            settingsView5.storedIndex = settingsView5.currentIndex;
                            settingsView6.storedIndex = settingsView6.currentIndex;
                        }
                    }
                }
                Keys.onReleased: {
                    // If there is only one spin wheel, then close dialog
                    if (event.key === keys.left && nextModels == 1)
                        hide()
                }
            }

            Text {
                text: settingsView1.model === undefined ? " " : settingsView1.model.delimiter
                anchors.verticalCenter: settingsView1.verticalCenter
                width: text === "" ? 0 : 5
                color: colors.textNormal
                font.pixelSize: fonts.smallSize
                font.family: fonts.family
            }

            ValueSelectorList {
                id: settingsView2
                KeyNavigation.left: settingsView1
                KeyNavigation.right: nextModels > 2 ? settingsView3 : settingsView2
            }

            Text {
                text: nextModels < 2 ? "" : settingsView2.model.delimiter
                anchors.verticalCenter: settingsView1.verticalCenter
                width: text === "" ? 0 : 5
                color: colors.textNormal
                font.pixelSize: fonts.smallSize
                font.family: fonts.family
            }

            ValueSelectorList {
                id: settingsView3
                KeyNavigation.left: settingsView2
                KeyNavigation.right: nextModels > 3 ? settingsView4 : settingsView3
            }

            Text {
                text: nextModels < 3 ? "" : settingsView3.model.delimiter
                anchors.verticalCenter: settingsView1.verticalCenter
                width: text === "" ? 0 : 5
                color: colors.textNormal
                font.pixelSize: fonts.smallSize
                font.family: fonts.family
            }

            ValueSelectorList {
                id: settingsView4
                KeyNavigation.left: settingsView3
                KeyNavigation.right: nextModels > 4 ? settingsView5 : settingsView4
            }

            Text {
                text: nextModels < 4 ? "" : settingsView4.model.delimiter
                anchors.verticalCenter: settingsView1.verticalCenter
                width: text === "" ? 0 : 5
                color: colors.textNormal
                font.pixelSize: fonts.smallSize
                font.family: fonts.family
            }

            ValueSelectorList {
                id: settingsView5
                KeyNavigation.left: settingsView4
                KeyNavigation.right: nextModels > 5 ? settingsView6 : settingsView5
            }

            Text {
                text: nextModels < 5 ? "" : settingsView5.model.delimiter
                anchors.verticalCenter: settingsView1.verticalCenter
                width: text === "" ? 0 : 5
                color: colors.textNormal
                font.pixelSize: fonts.smallSize
                font.family: fonts.family
            }

            ValueSelectorList {
                id: settingsView6
                KeyNavigation.left: settingsView5
                KeyNavigation.right: settingsView6
            }

            Text {
                text: nextModels < 6 ? "" : settingsView6.model.delimiter
                anchors.verticalCenter: settingsView1.verticalCenter
                width: text === "" ? 0 : 5
                color: colors.textNormal
                font.pixelSize: fonts.smallSize
                font.family: fonts.family
            }
        }

        // Dialog footer

        SettingsFooter {
            id: footerText
            text: settingsView1.model === undefined ? "" : settingsView1.model.tooltip
            icon: (settingsView1.model === undefined || settingsView1.model.tooltipIcon === undefined || settingsView1.model.tooltipIcon === "") ? "" : "../images/" + settingsView1.model.tooltipIcon
        }
    }
}
