import QtQuick 1.1
import GreenBox 1.0

// SaveStatus
// ----------
// The save status, shown in the bottom left corner while saving.

Item {

    // Property values
    id: videoRecordStatus
    anchors.horizontalCenter: parent.horizontalCenter
    y: grid.topMargin + grid.verticalSpacing


    width: animatedImage.anchors.leftMargin * 3 + animatedImage.width + recStatusText.width
    height: backgroundImage.height
    visible: (greenbox.mediaControl.mediaControlVisual === MediaControl.MEDIA_CONTROL_VISUAL_VIDEO_IDLE ||
              greenbox.mediaControl.mediaControlVisual === MediaControl.MEDIA_CONTROL_VISUAL_VIDEO_PENDINGSTOP ||
              greenbox.mediaControl.mediaControlVisual === MediaControl.MEDIA_CONTROL_VISUAL_VIDEO_RECORDING) &&
             (greenbox.appState === GreenBox.FacetLiveView ||
              greenbox.appState === GreenBox.FacetMediaControlState)

    // The background
    BorderImage {
        id: backgroundImage
        width: videoRecordStatus.width
        border { left: grid.unit; top: grid.unit; right: grid.unit; bottom: grid.unit }
        source: "../images/Bg_Notification_Bar_Def.png"
    }


    // The animated image
    Item {
        id: animatedImage
        width: 10
        height: 10
        anchors.left: parent.left
        anchors.leftMargin: (parent.height - height ) /2
        anchors.verticalCenter: parent.verticalCenter

        Rectangle {
            anchors.fill: parent
            radius: width
            smooth: true
            visible: (greenbox.mediaControl.mediaControlVisual === MediaControl.MEDIA_CONTROL_VISUAL_VIDEO_IDLE)
            color: "darkgray"
        }

        Spinner {
            anchors.fill: parent
            visible: (greenbox.mediaControl.mediaControlVisual === MediaControl.MEDIA_CONTROL_VISUAL_VIDEO_PENDINGSTOP)
        }

        Rectangle {
            id: recIndicator
            visible: (greenbox.mediaControl.mediaControlVisual === MediaControl.MEDIA_CONTROL_VISUAL_VIDEO_RECORDING)
            anchors.fill: parent
            radius: width / 2
            smooth: true
            color: "#F00000"

            Timer {
                interval: 1000
                repeat: true
                running: recIndicator.visible
                onTriggered: {
                    if(recIndicator.color == "#000000")
                        recIndicator.color = "#F00000"
                    else
                        recIndicator.color = "black"
                }
            }
        }
    }

    // The text labels
    Text {
        id: recStatusText
        anchors.left: animatedImage.right
        anchors.leftMargin: animatedImage.anchors.leftMargin
        anchors.verticalCenter: parent.verticalCenter
        font.family: fonts.family
        font.pixelSize: fonts.smallSize
        color: colors.textNormal
        text: greenbox.mediaControl.elapsedTime
    }
}
