import QtQuick 1.1

//
// ListView delegate used by WirelessSettingsPage
//

//Rectangle {
Item {
    property variant model
    property variant view

    // Expose model data (only components can be aliased)
    property variant delegateNextModel:         model.nextModel
    property string delegateNextQML:            model.nextQML
    property string delegateID:                 model.ID
    property string delegateLabel:              model.label
    property string delegateValue:              model.value
    property string delegateSettingType:        model.settingType
    property bool   delegateSettingRadio:       model.radio
    property bool   delegateSettingCheckBox:    model.checkBox
    property bool   delegateItemEnabled:        model.itemEnabled
    property string delegateConfirmMsg:         model.confirmMsg
    property string delegateConfirmText:        model.confirmText
    property string delegateConfirmIcon:        model.confirmIcon
    property string delegateConfirmCancel:      model.confirmCancel
    property string delegateConfirmOk:          model.confirmOk
    property string delegateFooterTitle:        model.itemFooterArgument === ""
                                                || model.itemFooterArgument === undefined
                                                ? qsTrId(model.itemFooter)
                                                : qsTrId(model.itemFooter).arg(model.itemFooterArgument)
    property bool   delegateAutoHidePage:       model.autoHidePage !== undefined ? model.autoHidePage : false
    property bool   delegateVisible:            model.visible !== undefined ? model.visible : true

    // Properties used for multi model settings
    property variant delegateNextModels: model.nextModels
    property variant delegateNextModel1: model.nextModel1
    property variant delegateNextModel2: model.nextModel2
    property variant delegateNextModel3: model.nextModel3
    property variant delegateNextModel4: model.nextModel4
    property variant delegateNextModel5: model.nextModel5
    property variant delegateNextModel6: model.nextModel6

    signal clicked()

    id: wirelessSettingsDelegate

    visible: delegateVisible
    width: view.width
    height: visible ? grid.cellHeight + grid.verticalSpacing : 0

//    color: Qt.rgba(Math.random(), Math.random(), Math.random(), 1)
//    opacity: 0.3

//    Rectangle {
//        anchors.fill: settingTextItem
//        color: "red"
//        opacity: 0.2
//    }

//    Rectangle {
//        anchors.fill: icon2Image
//        color: "green"
//        opacity: 0.5
//    }

//    Rectangle {
//        anchors.fill: icon1Image
//        color: "purple"
//        opacity: 0.5
//    }

//    Rectangle {
//        anchors.fill: checkableImage
//        color: "orange"
//        opacity: 0.5
//    }

//    Rectangle {
//        anchors.fill: arrowImage
//        color: "white"
//        opacity: 0.5
//    }

//    Rectangle {
//        anchors.fill: valueTextItem
//        color: "blue"
//        opacity: 0.5
//    }

    Text {
        id: settingTextItem
        anchors.left: parent.left
        anchors.leftMargin: model.indented !== undefined && model.indented
                            ? grid.unit*10 : grid.unit*5
        anchors.right: icon2Image.left
        anchors.verticalCenter: parent.verticalCenter
        color: model.itemEnabled ? (isCurrentItem ? colors.textFocused : colors.textNormal) : colors.textDisabled

        // Adjust this one for right-to-left languages!
        elide: Text.ElideRight

        font.pixelSize: fonts.smallSize
        font.family: model.label !== "" ? fonts.family : (model.specialFont === "" ? fonts.family : model.specialFont)
        text: model.label !== "" ?
                  qsTrId(model.label) + translation.update :
                  (model.translateValue ?
                       (model.value2 === undefined || model.value2 === "" ? qsTrId(model.value) : qsTrId(model.value).arg(model.value2)) + translation.update :
                       model.value + (model.value2 === undefined ? "" : model.value2))
    }

    Image {
        id: checkableImage
        anchors.right: arrowImage.left
        anchors.rightMargin: model.radio || model.checkBox ? 3 * grid.horizontalSpacing : 0
        anchors.verticalCenter: parent.verticalCenter
        source: model.radio ?
                    "../images/Ic_ListChoice_RadioButton" +
                    (model.checked ? "Checked" : "") +
                    (isCurrentItem ? "_Sel.png" : "_Def.png")
                  : (model.checkBox ?
                         "../images/Ic_ListChoice_CheckBox" + (model.checked ? "Checked" : "") +
                         (isCurrentItem ? "_Sel.png" : "_Def.png") : "")
        visible: (model.radio || model.checkBox) && model.nextQML === ""
        width: visible ? source.width : 0
    }

    Image {
        id: arrowImage
        anchors.right: parent.right
        anchors.rightMargin: grid.horizontalSpacing
        anchors.verticalCenter: parent.verticalCenter
        source: "../images/Ic_List_ArrowRight" + (isCurrentItem ? "_Sel.png" : "_Def.png")
        visible: model.nextQML !== ""
        width: visible ? source.width : 0
    }

    Text {
        id: valueTextItem
        // Always align after the arrowImage if the checkableImage is not
        // visible.
        anchors.right: checkableImage.visible ? checkableImage.left : arrowImage.left
        anchors.rightMargin: checkableImage.visible ? 0 : grid.horizontalSpacing * 3
        anchors.verticalCenter: parent.verticalCenter
        color: isCurrentItem ? colors.textNormal : colors.textDisabled
        font.pixelSize: fonts.smallSize
        font.family: model.specialFont === "" ? fonts.family : model.specialFont
        text: model.value === "" || model.value === undefined || model.label === ""
              ? ""
              : model.translateValue
                ? qsTrId(model.value) + translation.update
                : model.value

        // Adjust this one for right-to-left languages!
        elide: Text.ElideRight
    }

    Image {
        id: icon2Image
        anchors.right: icon1Image.left
        anchors.rightMargin: grid.unit*3
        anchors.verticalCenter: parent.verticalCenter

        visible: model.icon2 !== undefined && model.icon2 !== ""
        source: model.icon2 !== undefined && model.icon2 !== "" ? "../images/" + model.icon2 + ".png" : ""

        width: visible ? source.width : 0
        opacity: visible ? (isCurrentItem ? 1.0 : 0.55) : 0.0
    }

    Image {
        id: icon1Image
        anchors.right: checkableImage.left
        anchors.rightMargin: grid.unit*3
        anchors.verticalCenter: parent.verticalCenter

        visible: model.icon !== undefined && model.icon !== ""
        source: model.icon !== undefined && model.icon !== "" ? "../images/" + model.icon + "_Def.png" : ""

        width: visible ? source.width : 0
//        opacity: visible ? (isCurrentItem ? 1.0 : 0.55) : 0.0
    }

    MouseArea {
        anchors.fill: parent
        onClicked: {
            view.currentIndex = model.index
            wirelessSettingsDelegate.clicked()
        }

        // For possible future functionality.
        //onPressAndHold: {
        //    view.currentIndex = model.index
        //}
    }
}
